# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/broadcast_v1/broadcast.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.video/coordinator/broadcast_v1/broadcast.proto\x12%stream.video.coordinator.broadcast_v1\"\x1b\n\x0bRTMPOptions\x12\x0c\n\x04urls\x18\x01 \x03(\t\"^\n\tBroadcast\x12@\n\x04rtmp\x18\x01 \x01(\x0b\x32\x32.stream.video.coordinator.broadcast_v1.RTMPOptions\x12\x0f\n\x07hls_url\x18\x02 \x01(\t*A\n\x05\x43odec\x12\x1a\n\x16\x43ODEC_H264_UNSPECIFIED\x10\x00\x12\r\n\tCODEC_VP8\x10\x01\x12\r\n\tCODEC_VP9\x10\x02\x42;B\x0b\x42roadcastV1P\x01Z\x0c\x62roadcast_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.broadcast_v1.broadcast_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\013BroadcastV1P\001Z\014broadcast_v1\252\002\033Stream.Video.v1.Coordinator'
  _CODEC._serialized_start=214
  _CODEC._serialized_end=279
  _RTMPOPTIONS._serialized_start=89
  _RTMPOPTIONS._serialized_end=116
  _BROADCAST._serialized_start=118
  _BROADCAST._serialized_end=212
# @@protoc_insertion_point(module_scope)
