# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/utils_v1/utils.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&video/coordinator/utils_v1/utils.proto\x12!stream.video.coordinator.utils_v1\"V\n\x04Sort\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12?\n\tdirection\x18\x02 \x01(\x0e\x32,.stream.video.coordinator.utils_v1.Direction*V\n\tDirection\x12\x19\n\x15\x44IRECTION_UNSPECIFIED\x10\x00\x12\x1b\n\x0e\x44IRECTION_DESC\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x11\n\rDIRECTION_ASC\x10\x01\x42\x33\x42\x07UtilsV1P\x01Z\x08utils_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.utils_v1.utils_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\007UtilsV1P\001Z\010utils_v1\252\002\033Stream.Video.v1.Coordinator'
  _DIRECTION._serialized_start=165
  _DIRECTION._serialized_end=251
  _SORT._serialized_start=77
  _SORT._serialized_end=163
# @@protoc_insertion_point(module_scope)
