# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/client_v1_rpc/websocket.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2
from video.coordinator.event_v1 import event_pb2 as video_dot_coordinator_dot_event__v1_dot_event__pb2
from video.coordinator.push_v1 import push_pb2 as video_dot_coordinator_dot_push__v1_dot_push__pb2
from video.coordinator.user_v1 import user_pb2 as video_dot_coordinator_dot_user__v1_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/video/coordinator/client_v1_rpc/websocket.proto\x12&stream.video.coordinator.client_v1_rpc\x1a\x17validate/validate.proto\x1a&video/coordinator/event_v1/event.proto\x1a$video/coordinator/push_v1/push.proto\x1a$video/coordinator/user_v1/user.proto\"\xa5\t\n\x0eWebsocketEvent\x12P\n\x05users\x18\x01 \x03(\x0b\x32\x41.stream.video.coordinator.client_v1_rpc.WebsocketEvent.UsersEntry\x12S\n\x0bhealthcheck\x18\x14 \x01(\x0b\x32<.stream.video.coordinator.client_v1_rpc.WebsocketHealthcheckH\x00\x12\x46\n\x0c\x63\x61ll_created\x18\x1e \x01(\x0b\x32..stream.video.coordinator.event_v1.CallCreatedH\x00\x12\x46\n\x0c\x63\x61ll_updated\x18\x1f \x01(\x0b\x32..stream.video.coordinator.event_v1.CallUpdatedH\x00\x12\x46\n\x0c\x63\x61ll_deleted\x18  \x01(\x0b\x32..stream.video.coordinator.event_v1.CallDeletedH\x00\x12U\n\x14\x63\x61ll_members_created\x18! \x01(\x0b\x32\x35.stream.video.coordinator.event_v1.CallMembersCreatedH\x00\x12U\n\x14\x63\x61ll_members_updated\x18\" \x01(\x0b\x32\x35.stream.video.coordinator.event_v1.CallMembersUpdatedH\x00\x12U\n\x14\x63\x61ll_members_deleted\x18# \x01(\x0b\x32\x35.stream.video.coordinator.event_v1.CallMembersDeletedH\x00\x12\x42\n\ncall_ended\x18$ \x01(\x0b\x32,.stream.video.coordinator.event_v1.CallEndedH\x00\x12H\n\rcall_accepted\x18( \x01(\x0b\x32/.stream.video.coordinator.event_v1.CallAcceptedH\x00\x12H\n\rcall_rejected\x18) \x01(\x0b\x32/.stream.video.coordinator.event_v1.CallRejectedH\x00\x12J\n\x0e\x63\x61ll_cancelled\x18* \x01(\x0b\x32\x30.stream.video.coordinator.event_v1.CallCancelledH\x00\x12\x46\n\x0cuser_updated\x18\x32 \x01(\x0b\x32..stream.video.coordinator.event_v1.UserUpdatedH\x00\x12\x44\n\x0b\x63\x61ll_custom\x18\x63 \x01(\x0b\x32-.stream.video.coordinator.event_v1.CallCustomH\x00\x1aT\n\nUsersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.stream.video.coordinator.user_v1.User:\x02\x38\x01\x42\x07\n\x05\x65vent\"\xca\x01\n\x14WebsocketClientEvent\x12S\n\x0bhealthcheck\x18\x01 \x01(\x0b\x32<.stream.video.coordinator.client_v1_rpc.WebsocketHealthcheckH\x00\x12T\n\x0c\x61uth_request\x18\x02 \x01(\x0b\x32<.stream.video.coordinator.client_v1_rpc.WebsocketAuthRequestH\x00\x42\x07\n\x05\x65vent\"\xb0\x01\n\x14WebsocketAuthRequest\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x39\n\x04user\x18\x03 \x01(\x0b\x32+.stream.video.coordinator.user_v1.UserInput\x12=\n\x06\x64\x65vice\x18\x04 \x01(\x0b\x32-.stream.video.coordinator.push_v1.DeviceInput\"\x8e\x01\n\x14WebsocketHealthcheck\x12\x18\n\x07user_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1a\n\tclient_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x11\n\tcall_type\x18\x03 \x01(\t\x12\x0f\n\x07\x63\x61ll_id\x18\x04 \x01(\t\x12\r\n\x05video\x18\x05 \x01(\x08\x12\r\n\x05\x61udio\x18\x06 \x01(\x08\x42@B\x11\x43lientV1WebsocketZ\rclient_v1_rpc\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.client_v1_rpc.websocket_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\021ClientV1WebsocketZ\rclient_v1_rpc\252\002\033Stream.Video.v1.Coordinator'
  _WEBSOCKETEVENT_USERSENTRY._options = None
  _WEBSOCKETEVENT_USERSENTRY._serialized_options = b'8\001'
  _WEBSOCKETHEALTHCHECK.fields_by_name['user_id']._options = None
  _WEBSOCKETHEALTHCHECK.fields_by_name['user_id']._serialized_options = b'\372B\004r\002\020\001'
  _WEBSOCKETHEALTHCHECK.fields_by_name['client_id']._options = None
  _WEBSOCKETHEALTHCHECK.fields_by_name['client_id']._serialized_options = b'\372B\004r\002\020\001'
  _WEBSOCKETEVENT._serialized_start=233
  _WEBSOCKETEVENT._serialized_end=1422
  _WEBSOCKETEVENT_USERSENTRY._serialized_start=1329
  _WEBSOCKETEVENT_USERSENTRY._serialized_end=1413
  _WEBSOCKETCLIENTEVENT._serialized_start=1425
  _WEBSOCKETCLIENTEVENT._serialized_end=1627
  _WEBSOCKETAUTHREQUEST._serialized_start=1630
  _WEBSOCKETAUTHREQUEST._serialized_end=1806
  _WEBSOCKETHEALTHCHECK._serialized_start=1809
  _WEBSOCKETHEALTHCHECK._serialized_end=1951
# @@protoc_insertion_point(module_scope)
