# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/server_v1_rpc/envelopes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video.coordinator.call_v1 import call_pb2 as video_dot_coordinator_dot_call__v1_dot_call__pb2
from video.coordinator.member_v1 import member_pb2 as video_dot_coordinator_dot_member__v1_dot_member__pb2
from video.coordinator.recording_v1 import recording_pb2 as video_dot_coordinator_dot_recording__v1_dot_recording__pb2
from video.coordinator.user_v1 import user_pb2 as video_dot_coordinator_dot_user__v1_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/video/coordinator/server_v1_rpc/envelopes.proto\x12&stream.video.coordinator.server_v1_rpc\x1a$video/coordinator/call_v1/call.proto\x1a(video/coordinator/member_v1/member.proto\x1a.video/coordinator/recording_v1/recording.proto\x1a$video/coordinator/user_v1/user.proto\"\xfd\x02\n\x12\x45xportUserEnvelope\x12\x34\n\x04user\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.user_v1.User\x12\x35\n\x05\x63\x61lls\x18\x02 \x03(\x0b\x32&.stream.video.coordinator.call_v1.Call\x12X\n\x07members\x18\x03 \x03(\x0b\x32G.stream.video.coordinator.server_v1_rpc.ExportUserEnvelope.MembersEntry\x12\x44\n\nrecordings\x18\x04 \x03(\x0b\x32\x30.stream.video.coordinator.recording_v1.Recording\x1aZ\n\x0cMembersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.stream.video.coordinator.member_v1.Member:\x02\x38\x01\x42\x0fZ\rserver_v1_rpcb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.server_v1_rpc.envelopes_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\rserver_v1_rpc'
  _EXPORTUSERENVELOPE_MEMBERSENTRY._options = None
  _EXPORTUSERENVELOPE_MEMBERSENTRY._serialized_options = b'8\001'
  _EXPORTUSERENVELOPE._serialized_start=258
  _EXPORTUSERENVELOPE._serialized_end=639
  _EXPORTUSERENVELOPE_MEMBERSENTRY._serialized_start=549
  _EXPORTUSERENVELOPE_MEMBERSENTRY._serialized_end=639
# @@protoc_insertion_point(module_scope)
