# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/client_v1_rpc/envelopes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video.coordinator.call_v1 import call_pb2 as video_dot_coordinator_dot_call__v1_dot_call__pb2
from video.coordinator.member_v1 import member_pb2 as video_dot_coordinator_dot_member__v1_dot_member__pb2
from video.coordinator.user_v1 import user_pb2 as video_dot_coordinator_dot_user__v1_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/video/coordinator/client_v1_rpc/envelopes.proto\x12&stream.video.coordinator.client_v1_rpc\x1a$video/coordinator/call_v1/call.proto\x1a(video/coordinator/member_v1/member.proto\x1a$video/coordinator/user_v1/user.proto\"\xaa\x02\n\x0c\x43\x61llEnvelope\x12N\n\x05users\x18\x01 \x03(\x0b\x32?.stream.video.coordinator.client_v1_rpc.CallEnvelope.UsersEntry\x12\x34\n\x04\x63\x61ll\x18\x02 \x01(\x0b\x32&.stream.video.coordinator.call_v1.Call\x12>\n\x07\x64\x65tails\x18\x03 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetails\x1aT\n\nUsersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.stream.video.coordinator.user_v1.User:\x02\x38\x01\"\xa4\x04\n\rCallsEnvelope\x12O\n\x05users\x18\x01 \x03(\x0b\x32@.stream.video.coordinator.client_v1_rpc.CallsEnvelope.UsersEntry\x12\x11\n\tcall_cids\x18\x02 \x03(\t\x12O\n\x05\x63\x61lls\x18\x03 \x03(\x0b\x32@.stream.video.coordinator.client_v1_rpc.CallsEnvelope.CallsEntry\x12S\n\x07\x64\x65tails\x18\x04 \x03(\x0b\x32\x42.stream.video.coordinator.client_v1_rpc.CallsEnvelope.DetailsEntry\x1aT\n\nUsersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.stream.video.coordinator.user_v1.User:\x02\x38\x01\x1aT\n\nCallsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.stream.video.coordinator.call_v1.Call:\x02\x38\x01\x1a]\n\x0c\x44\x65tailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12<\n\x05value\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetails:\x02\x38\x01\"\x86\x03\n\x0fMembersEnvelope\x12Q\n\x05users\x18\x01 \x03(\x0b\x32\x42.stream.video.coordinator.client_v1_rpc.MembersEnvelope.UsersEntry\x12\x17\n\x0fmember_user_ids\x18\x02 \x03(\t\x12U\n\x07members\x18\x03 \x03(\x0b\x32\x44.stream.video.coordinator.client_v1_rpc.MembersEnvelope.MembersEntry\x1aT\n\nUsersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.stream.video.coordinator.user_v1.User:\x02\x38\x01\x1aZ\n\x0cMembersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.stream.video.coordinator.member_v1.Member:\x02\x38\x01\x42@B\x11\x43lientV1EnvelopesZ\rclient_v1_rpc\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.client_v1_rpc.envelopes_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\021ClientV1EnvelopesZ\rclient_v1_rpc\252\002\033Stream.Video.v1.Coordinator'
  _CALLENVELOPE_USERSENTRY._options = None
  _CALLENVELOPE_USERSENTRY._serialized_options = b'8\001'
  _CALLSENVELOPE_USERSENTRY._options = None
  _CALLSENVELOPE_USERSENTRY._serialized_options = b'8\001'
  _CALLSENVELOPE_CALLSENTRY._options = None
  _CALLSENVELOPE_CALLSENTRY._serialized_options = b'8\001'
  _CALLSENVELOPE_DETAILSENTRY._options = None
  _CALLSENVELOPE_DETAILSENTRY._serialized_options = b'8\001'
  _MEMBERSENVELOPE_USERSENTRY._options = None
  _MEMBERSENVELOPE_USERSENTRY._serialized_options = b'8\001'
  _MEMBERSENVELOPE_MEMBERSENTRY._options = None
  _MEMBERSENVELOPE_MEMBERSENTRY._serialized_options = b'8\001'
  _CALLENVELOPE._serialized_start=210
  _CALLENVELOPE._serialized_end=508
  _CALLENVELOPE_USERSENTRY._serialized_start=424
  _CALLENVELOPE_USERSENTRY._serialized_end=508
  _CALLSENVELOPE._serialized_start=511
  _CALLSENVELOPE._serialized_end=1059
  _CALLSENVELOPE_USERSENTRY._serialized_start=424
  _CALLSENVELOPE_USERSENTRY._serialized_end=508
  _CALLSENVELOPE_CALLSENTRY._serialized_start=880
  _CALLSENVELOPE_CALLSENTRY._serialized_end=964
  _CALLSENVELOPE_DETAILSENTRY._serialized_start=966
  _CALLSENVELOPE_DETAILSENTRY._serialized_end=1059
  _MEMBERSENVELOPE._serialized_start=1062
  _MEMBERSENVELOPE._serialized_end=1452
  _MEMBERSENVELOPE_USERSENTRY._serialized_start=424
  _MEMBERSENVELOPE_USERSENTRY._serialized_end=508
  _MEMBERSENVELOPE_MEMBERSENTRY._serialized_start=1362
  _MEMBERSENVELOPE_MEMBERSENTRY._serialized_end=1452
# @@protoc_insertion_point(module_scope)
