"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class User(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TEAMS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def teams(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    custom_json: builtins.bytes
    name: builtins.str
    image_url: builtins.str
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """User creation date"""
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """User last update date."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        teams: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        custom_json: builtins.bytes = ...,
        name: builtins.str = ...,
        image_url: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "custom_json", b"custom_json", "id", b"id", "image_url", b"image_url", "name", b"name", "role", b"role", "teams", b"teams", "updated_at", b"updated_at"]) -> None: ...

global___User = User

class UserInput(google.protobuf.message.Message):
    """A message that is used in User requests to create and modify user data"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TEAMS_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    name: builtins.str
    """A human-readable name of the user"""
    role: builtins.str
    """User role, as defined by permission settings"""
    @property
    def teams(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of user teams for multi-tenant applications"""
    image_url: builtins.str
    """A URL that points to a user image"""
    custom_json: builtins.bytes
    """A JSON object with custom user information"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        role: builtins.str = ...,
        teams: collections.abc.Iterable[builtins.str] | None = ...,
        image_url: builtins.str = ...,
        custom_json: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_json", b"custom_json", "image_url", b"image_url", "name", b"name", "role", b"role", "teams", b"teams"]) -> None: ...

global___UserInput = UserInput
