# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/recording_v1/recording.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.video/coordinator/recording_v1/recording.proto\x12%stream.video.coordinator.recording_v1\"k\n\tRecording\x12\x11\n\tcall_type\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61ll_id\x18\x02 \x01(\t\x12\x13\n\x0bs3_file_url\x18\x03 \x01(\t\x12\x12\n\nstart_time\x18\x04 \x01(\t\x12\x11\n\tstop_time\x18\x05 \x01(\t\"E\n\x04\x46ile\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x11\n\tcomposite\x18\x02 \x01(\x08\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\"`\n\x0fRecordBroadcast\x12\x11\n\tcomposite\x18\x01 \x01(\x08\x12:\n\x05\x66iles\x18\x02 \x03(\x0b\x32+.stream.video.coordinator.recording_v1.File\"\xbe\x01\n\x17RecordingStorageOptions\x12H\n\x07storage\x18\x01 \x01(\x0e\x32\x37.stream.video.coordinator.recording_v1.RecordingStorage\x12\x12\n\naccess_key\x18\x02 \x01(\t\x12\x12\n\nsecret_key\x18\x03 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x0c\n\x04path\x18\x06 \x01(\t*8\n\x10RecordingStorage\x12$\n RECORDING_STORAGE_S3_UNSPECIFIED\x10\x00\x42;B\x0bRecordingV1P\x01Z\x0crecording_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.recording_v1.recording_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\013RecordingV1P\001Z\014recording_v1\252\002\033Stream.Video.v1.Coordinator'
  _RECORDINGSTORAGE._serialized_start=560
  _RECORDINGSTORAGE._serialized_end=616
  _RECORDING._serialized_start=89
  _RECORDING._serialized_end=196
  _FILE._serialized_start=198
  _FILE._serialized_end=267
  _RECORDBROADCAST._serialized_start=269
  _RECORDBROADCAST._serialized_end=365
  _RECORDINGSTORAGEOPTIONS._serialized_start=368
  _RECORDINGSTORAGEOPTIONS._serialized_end=558
# @@protoc_insertion_point(module_scope)
