# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/client_v1_rpc/client_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from video.coordinator.call_v1 import call_pb2 as video_dot_coordinator_dot_call__v1_dot_call__pb2
from video.coordinator.client_v1_rpc import envelopes_pb2 as video_dot_coordinator_dot_client__v1__rpc_dot_envelopes__pb2
from video.coordinator.edge_v1 import edge_pb2 as video_dot_coordinator_dot_edge__v1_dot_edge__pb2
from video.coordinator.push_v1 import push_pb2 as video_dot_coordinator_dot_push__v1_dot_push__pb2
from video.coordinator.stat_v1 import stat_pb2 as video_dot_coordinator_dot_stat__v1_dot_stat__pb2
from video.coordinator.utils_v1 import utils_pb2 as video_dot_coordinator_dot_utils__v1_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0video/coordinator/client_v1_rpc/client_rpc.proto\x12&stream.video.coordinator.client_v1_rpc\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$video/coordinator/call_v1/call.proto\x1a/video/coordinator/client_v1_rpc/envelopes.proto\x1a$video/coordinator/edge_v1/edge.proto\x1a$video/coordinator/push_v1/push.proto\x1a$video/coordinator/stat_v1/stat.proto\x1a&video/coordinator/utils_v1/utils.proto\"\"\n\x0eGetCallRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\"U\n\x0fGetCallResponse\x12\x42\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x34.stream.video.coordinator.client_v1_rpc.CallEnvelope\"A\n\x0bMemberInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x13\n\x0b\x63ustom_json\x18\x03 \x01(\x0c\"\x80\x01\n\x18UpsertCallMembersRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12\x44\n\x07members\x18\x02 \x03(\x0b\x32\x33.stream.video.coordinator.client_v1_rpc.MemberInput\x12\x0c\n\x04ring\x18\x03 \x01(\x08\"\x1b\n\x19UpsertCallMembersResponse\">\n\x18\x44\x65leteCallMembersRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12\x10\n\x08user_ids\x18\x02 \x03(\t\"\x1b\n\x19\x44\x65leteCallMembersResponse\"\xb4\x01\n\x0f\x43reateCallInput\x12?\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x31.stream.video.coordinator.client_v1_rpc.CallInput\x12\x44\n\x07members\x18\x02 \x03(\x0b\x32\x33.stream.video.coordinator.client_v1_rpc.MemberInput\x12\x11\n\x04ring\x18\x04 \x01(\x08H\x00\x88\x01\x01\x42\x07\n\x05_ring\"\x81\x01\n\x11\x43reateCallRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x02id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x46\n\x05input\x18\x03 \x01(\x0b\x32\x37.stream.video.coordinator.client_v1_rpc.CreateCallInputB\x05\n\x03_id\"z\n\x16GetOrCreateCallRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x46\n\x05input\x18\x03 \x01(\x0b\x32\x37.stream.video.coordinator.client_v1_rpc.CreateCallInput\"\x8a\x01\n\x0fJoinCallRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x46\n\x05input\x18\x03 \x01(\x0b\x32\x37.stream.video.coordinator.client_v1_rpc.CreateCallInput\x12\x15\n\rdatacenter_id\x18\x04 \x01(\t\"\x9e\x01\n\x10JoinCallResponse\x12\x42\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x34.stream.video.coordinator.client_v1_rpc.CallEnvelope\x12\x0f\n\x07\x63reated\x18\x02 \x01(\x08\x12\x35\n\x05\x65\x64ges\x18\x03 \x03(\x0b\x32&.stream.video.coordinator.edge_v1.Edge\"`\n\tCallInput\x12\x13\n\x0b\x63ustom_json\x18\x01 \x01(\x0c\x12>\n\x07options\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallOptions\"n\n\x17GetOrCreateCallResponse\x12\x42\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x34.stream.video.coordinator.client_v1_rpc.CallEnvelope\x12\x0f\n\x07\x63reated\x18\x02 \x01(\x08\"g\n\x11UpdateCallRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12@\n\x05input\x18\x02 \x01(\x0b\x32\x31.stream.video.coordinator.client_v1_rpc.CallInput\"X\n\x12UpdateCallResponse\x12\x42\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x34.stream.video.coordinator.client_v1_rpc.CallEnvelope\"X\n\x12\x43reateCallResponse\x12\x42\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x34.stream.video.coordinator.client_v1_rpc.CallEnvelope\"z\n\x11QueryCallsRequest\x12\x0f\n\x07mq_json\x18\x01 \x01(\x0c\x12\x12\n\x05limit\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x36\n\x05sorts\x18\x03 \x03(\x0b\x32\'.stream.video.coordinator.utils_v1.SortB\x08\n\x06_limit\"Z\n\x12QueryCallsResponse\x12\x44\n\x05\x63\x61lls\x18\x01 \x01(\x0b\x32\x35.stream.video.coordinator.client_v1_rpc.CallsEnvelope\"|\n\x13QueryMembersRequest\x12\x0f\n\x07mq_json\x18\x01 \x01(\x0c\x12\x12\n\x05limit\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x36\n\x05sorts\x18\x03 \x03(\x0b\x32\'.stream.video.coordinator.utils_v1.SortB\x08\n\x06_limit\"`\n\x14QueryMembersResponse\x12H\n\x07members\x18\x01 \x01(\x0b\x32\x37.stream.video.coordinator.client_v1_rpc.MembersEnvelope\"y\n\x18GetCallEdgeServerRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12K\n\x0cmeasurements\x18\x02 \x01(\x0b\x32\x35.stream.video.coordinator.edge_v1.LatencyMeasurements\"\xa3\x01\n\x19GetCallEdgeServerResponse\x12\x42\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x34.stream.video.coordinator.client_v1_rpc.CallEnvelope\x12\x42\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.edge_v1.Credentials\"S\n\x13\x43reateDeviceRequest\x12<\n\x05input\x18\x01 \x01(\x0b\x32-.stream.video.coordinator.push_v1.DeviceInput\"P\n\x14\x43reateDeviceResponse\x12\x38\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32(.stream.video.coordinator.push_v1.Device\"!\n\x13\x44\x65leteDeviceRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteDeviceResponse\"\x15\n\x13QueryDevicesRequest\"Q\n\x14QueryDevicesResponse\x12\x39\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32(.stream.video.coordinator.push_v1.Device\"o\n\x10SendEventRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12I\n\nevent_type\x18\x02 \x01(\x0e\x32\x35.stream.video.coordinator.client_v1_rpc.UserEventType\"\x13\n\x11SendEventResponse\"K\n\x16SendCustomEventRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x11\n\tdata_json\x18\x03 \x01(\x0c\"\x19\n\x17SendCustomEventResponse\">\n\x16ReportCallStatsRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12\x12\n\nstats_json\x18\x02 \x01(\x0c\"\x19\n\x17ReportCallStatsResponse\"\xba\x01\n\x1aReportCallStatEventRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12R\n\x13media_state_changed\x18\x03 \x01(\x0b\x32\x33.stream.video.coordinator.stat_v1.MediaStateChangedH\x00\x42\x07\n\x05\x65vent\"\x1d\n\x1bReportCallStatEventResponse\"\'\n\x13GetCallStatsRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\"P\n\x12ReportIssueRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0b\x63ustom_json\x18\x03 \x01(\x0c\"\x15\n\x13ReportIssueResponse\"^\n\x11ReviewCallRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12\r\n\x05stars\x18\x02 \x01(\x02\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0b\x63ustom_json\x18\x04 \x01(\x0c\"\x14\n\x12ReviewCallResponse*\x9a\x01\n\rUserEventType\x12\x1f\n\x1bUSER_EVENT_TYPE_UNSPECIFIED\x10\x00\x12!\n\x1dUSER_EVENT_TYPE_ACCEPTED_CALL\x10\x01\x12!\n\x1dUSER_EVENT_TYPE_REJECTED_CALL\x10\x02\x12\"\n\x1eUSER_EVENT_TYPE_CANCELLED_CALL\x10\x03\x32\x8f\x14\n\tClientRPC\x12\x83\x01\n\nCreateCall\x12\x39.stream.video.coordinator.client_v1_rpc.CreateCallRequest\x1a:.stream.video.coordinator.client_v1_rpc.CreateCallResponse\x12\x92\x01\n\x0fGetOrCreateCall\x12>.stream.video.coordinator.client_v1_rpc.GetOrCreateCallRequest\x1a?.stream.video.coordinator.client_v1_rpc.GetOrCreateCallResponse\x12}\n\x08JoinCall\x12\x37.stream.video.coordinator.client_v1_rpc.JoinCallRequest\x1a\x38.stream.video.coordinator.client_v1_rpc.JoinCallResponse\x12\x98\x01\n\x11GetCallEdgeServer\x12@.stream.video.coordinator.client_v1_rpc.GetCallEdgeServerRequest\x1a\x41.stream.video.coordinator.client_v1_rpc.GetCallEdgeServerResponse\x12\x83\x01\n\nUpdateCall\x12\x39.stream.video.coordinator.client_v1_rpc.UpdateCallRequest\x1a:.stream.video.coordinator.client_v1_rpc.UpdateCallResponse\x12\x83\x01\n\nQueryCalls\x12\x39.stream.video.coordinator.client_v1_rpc.QueryCallsRequest\x1a:.stream.video.coordinator.client_v1_rpc.QueryCallsResponse\x12\x89\x01\n\x0cQueryMembers\x12;.stream.video.coordinator.client_v1_rpc.QueryMembersRequest\x1a<.stream.video.coordinator.client_v1_rpc.QueryMembersResponse\x12\x89\x01\n\x0c\x43reateDevice\x12;.stream.video.coordinator.client_v1_rpc.CreateDeviceRequest\x1a<.stream.video.coordinator.client_v1_rpc.CreateDeviceResponse\x12\x89\x01\n\x0c\x44\x65leteDevice\x12;.stream.video.coordinator.client_v1_rpc.DeleteDeviceRequest\x1a<.stream.video.coordinator.client_v1_rpc.DeleteDeviceResponse\x12\x89\x01\n\x0cQueryDevices\x12;.stream.video.coordinator.client_v1_rpc.QueryDevicesRequest\x1a<.stream.video.coordinator.client_v1_rpc.QueryDevicesResponse\x12\x98\x01\n\x11UpsertCallMembers\x12@.stream.video.coordinator.client_v1_rpc.UpsertCallMembersRequest\x1a\x41.stream.video.coordinator.client_v1_rpc.UpsertCallMembersResponse\x12\x98\x01\n\x11\x44\x65leteCallMembers\x12@.stream.video.coordinator.client_v1_rpc.DeleteCallMembersRequest\x1a\x41.stream.video.coordinator.client_v1_rpc.DeleteCallMembersResponse\x12\x80\x01\n\tSendEvent\x12\x38.stream.video.coordinator.client_v1_rpc.SendEventRequest\x1a\x39.stream.video.coordinator.client_v1_rpc.SendEventResponse\x12\x92\x01\n\x0fSendCustomEvent\x12>.stream.video.coordinator.client_v1_rpc.SendCustomEventRequest\x1a?.stream.video.coordinator.client_v1_rpc.SendCustomEventResponse\x12\x92\x01\n\x0fReportCallStats\x12>.stream.video.coordinator.client_v1_rpc.ReportCallStatsRequest\x1a?.stream.video.coordinator.client_v1_rpc.ReportCallStatsResponse\x12\x9e\x01\n\x13ReportCallStatEvent\x12\x42.stream.video.coordinator.client_v1_rpc.ReportCallStatEventRequest\x1a\x43.stream.video.coordinator.client_v1_rpc.ReportCallStatEventResponse\x12\x83\x01\n\nReviewCall\x12\x39.stream.video.coordinator.client_v1_rpc.ReviewCallRequest\x1a:.stream.video.coordinator.client_v1_rpc.ReviewCallResponse\x12\x86\x01\n\x0bReportIssue\x12:.stream.video.coordinator.client_v1_rpc.ReportIssueRequest\x1a;.stream.video.coordinator.client_v1_rpc.ReportIssueResponseB:B\x0b\x43lientV1RPCZ\rclient_v1_rpc\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.client_v1_rpc.client_rpc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\013ClientV1RPCZ\rclient_v1_rpc\252\002\033Stream.Video.v1.Coordinator'
  _USEREVENTTYPE._serialized_start=3920
  _USEREVENTTYPE._serialized_end=4074
  _GETCALLREQUEST._serialized_start=366
  _GETCALLREQUEST._serialized_end=400
  _GETCALLRESPONSE._serialized_start=402
  _GETCALLRESPONSE._serialized_end=487
  _MEMBERINPUT._serialized_start=489
  _MEMBERINPUT._serialized_end=554
  _UPSERTCALLMEMBERSREQUEST._serialized_start=557
  _UPSERTCALLMEMBERSREQUEST._serialized_end=685
  _UPSERTCALLMEMBERSRESPONSE._serialized_start=687
  _UPSERTCALLMEMBERSRESPONSE._serialized_end=714
  _DELETECALLMEMBERSREQUEST._serialized_start=716
  _DELETECALLMEMBERSREQUEST._serialized_end=778
  _DELETECALLMEMBERSRESPONSE._serialized_start=780
  _DELETECALLMEMBERSRESPONSE._serialized_end=807
  _CREATECALLINPUT._serialized_start=810
  _CREATECALLINPUT._serialized_end=990
  _CREATECALLREQUEST._serialized_start=993
  _CREATECALLREQUEST._serialized_end=1122
  _GETORCREATECALLREQUEST._serialized_start=1124
  _GETORCREATECALLREQUEST._serialized_end=1246
  _JOINCALLREQUEST._serialized_start=1249
  _JOINCALLREQUEST._serialized_end=1387
  _JOINCALLRESPONSE._serialized_start=1390
  _JOINCALLRESPONSE._serialized_end=1548
  _CALLINPUT._serialized_start=1550
  _CALLINPUT._serialized_end=1646
  _GETORCREATECALLRESPONSE._serialized_start=1648
  _GETORCREATECALLRESPONSE._serialized_end=1758
  _UPDATECALLREQUEST._serialized_start=1760
  _UPDATECALLREQUEST._serialized_end=1863
  _UPDATECALLRESPONSE._serialized_start=1865
  _UPDATECALLRESPONSE._serialized_end=1953
  _CREATECALLRESPONSE._serialized_start=1955
  _CREATECALLRESPONSE._serialized_end=2043
  _QUERYCALLSREQUEST._serialized_start=2045
  _QUERYCALLSREQUEST._serialized_end=2167
  _QUERYCALLSRESPONSE._serialized_start=2169
  _QUERYCALLSRESPONSE._serialized_end=2259
  _QUERYMEMBERSREQUEST._serialized_start=2261
  _QUERYMEMBERSREQUEST._serialized_end=2385
  _QUERYMEMBERSRESPONSE._serialized_start=2387
  _QUERYMEMBERSRESPONSE._serialized_end=2483
  _GETCALLEDGESERVERREQUEST._serialized_start=2485
  _GETCALLEDGESERVERREQUEST._serialized_end=2606
  _GETCALLEDGESERVERRESPONSE._serialized_start=2609
  _GETCALLEDGESERVERRESPONSE._serialized_end=2772
  _CREATEDEVICEREQUEST._serialized_start=2774
  _CREATEDEVICEREQUEST._serialized_end=2857
  _CREATEDEVICERESPONSE._serialized_start=2859
  _CREATEDEVICERESPONSE._serialized_end=2939
  _DELETEDEVICEREQUEST._serialized_start=2941
  _DELETEDEVICEREQUEST._serialized_end=2974
  _DELETEDEVICERESPONSE._serialized_start=2976
  _DELETEDEVICERESPONSE._serialized_end=2998
  _QUERYDEVICESREQUEST._serialized_start=3000
  _QUERYDEVICESREQUEST._serialized_end=3021
  _QUERYDEVICESRESPONSE._serialized_start=3023
  _QUERYDEVICESRESPONSE._serialized_end=3104
  _SENDEVENTREQUEST._serialized_start=3106
  _SENDEVENTREQUEST._serialized_end=3217
  _SENDEVENTRESPONSE._serialized_start=3219
  _SENDEVENTRESPONSE._serialized_end=3238
  _SENDCUSTOMEVENTREQUEST._serialized_start=3240
  _SENDCUSTOMEVENTREQUEST._serialized_end=3315
  _SENDCUSTOMEVENTRESPONSE._serialized_start=3317
  _SENDCUSTOMEVENTRESPONSE._serialized_end=3342
  _REPORTCALLSTATSREQUEST._serialized_start=3344
  _REPORTCALLSTATSREQUEST._serialized_end=3406
  _REPORTCALLSTATSRESPONSE._serialized_start=3408
  _REPORTCALLSTATSRESPONSE._serialized_end=3433
  _REPORTCALLSTATEVENTREQUEST._serialized_start=3436
  _REPORTCALLSTATEVENTREQUEST._serialized_end=3622
  _REPORTCALLSTATEVENTRESPONSE._serialized_start=3624
  _REPORTCALLSTATEVENTRESPONSE._serialized_end=3653
  _GETCALLSTATSREQUEST._serialized_start=3655
  _GETCALLSTATSREQUEST._serialized_end=3694
  _REPORTISSUEREQUEST._serialized_start=3696
  _REPORTISSUEREQUEST._serialized_end=3776
  _REPORTISSUERESPONSE._serialized_start=3778
  _REPORTISSUERESPONSE._serialized_end=3799
  _REVIEWCALLREQUEST._serialized_start=3801
  _REVIEWCALLREQUEST._serialized_end=3895
  _REVIEWCALLRESPONSE._serialized_start=3897
  _REVIEWCALLRESPONSE._serialized_end=3917
  _CLIENTRPC._serialized_start=4077
  _CLIENTRPC._serialized_end=6652
# @@protoc_insertion_point(module_scope)
