# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/stat_v1/stat.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$video/coordinator/stat_v1/stat.proto\x12 stream.video.coordinator.stat_v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\"\x16\n\x14ParticipantConnected\"\x19\n\x17ParticipantDisconnected\"\x90\x01\n\x06\x46reeze\x12?\n\nmedia_type\x18\x01 \x01(\x0e\x32+.stream.video.coordinator.stat_v1.MediaType\x12\x18\n\x07peer_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12+\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xa7\x02\n\x11MediaStateChanged\x12?\n\nmedia_type\x18\x01 \x01(\x0e\x32+.stream.video.coordinator.stat_v1.MediaType\x12\x42\n\x06\x63hange\x18\x02 \x01(\x0e\x32\x32.stream.video.coordinator.stat_v1.MediaStateChange\x12\x43\n\tdirection\x18\x03 \x01(\x0e\x32\x30.stream.video.coordinator.stat_v1.MediaDirection\x12H\n\x06reason\x18\x04 \x01(\x0e\x32\x38.stream.video.coordinator.stat_v1.MediaStateChangeReason\"\x90\x03\n\x0eTelemetryEvent\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12W\n\x15participant_connected\x18\x02 \x01(\x0b\x32\x36.stream.video.coordinator.stat_v1.ParticipantConnectedH\x00\x12]\n\x18participant_disconnected\x18\x03 \x01(\x0b\x32\x39.stream.video.coordinator.stat_v1.ParticipantDisconnectedH\x00\x12R\n\x13media_state_changed\x18\x04 \x01(\x0b\x32\x33.stream.video.coordinator.stat_v1.MediaStateChangedH\x00\x12:\n\x06\x66reeze\x18\x05 \x01(\x0b\x32(.stream.video.coordinator.stat_v1.FreezeH\x00\x42\x07\n\x05\x65vent\"\x92\x01\n\x17\x43\x61llParticipantTimeline\x12\x18\n\x07user_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1b\n\nsession_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12@\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x30.stream.video.coordinator.stat_v1.TelemetryEvent*S\n\tMediaType\x12\x1a\n\x16MEDIA_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10MEDIA_TYPE_AUDIO\x10\x01\x12\x14\n\x10MEDIA_TYPE_VIDEO\x10\x02*t\n\x10MediaStateChange\x12\"\n\x1eMEDIA_STATE_CHANGE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aMEDIA_STATE_CHANGE_STARTED\x10\x01\x12\x1c\n\x18MEDIA_STATE_CHANGE_ENDED\x10\x02*h\n\x0eMediaDirection\x12\x1f\n\x1bMEDIA_DIRECTION_UNSPECIFIED\x10\x00\x12\x18\n\x14MEDIA_DIRECTION_SEND\x10\x01\x12\x1b\n\x17MEDIA_DIRECTION_RECEIVE\x10\x02*\x91\x01\n\x16MediaStateChangeReason\x12)\n%MEDIA_STATE_CHANGE_REASON_UNSPECIFIED\x10\x00\x12\"\n\x1eMEDIA_STATE_CHANGE_REASON_MUTE\x10\x01\x12(\n$MEDIA_STATE_CHANGE_REASON_CONNECTION\x10\x02\x42\x31\x42\x06StatV1P\x01Z\x07stat_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.stat_v1.stat_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\006StatV1P\001Z\007stat_v1\252\002\033Stream.Video.v1.Coordinator'
  _FREEZE.fields_by_name['peer_id']._options = None
  _FREEZE.fields_by_name['peer_id']._serialized_options = b'\372B\004r\002\020\001'
  _CALLPARTICIPANTTIMELINE.fields_by_name['user_id']._options = None
  _CALLPARTICIPANTTIMELINE.fields_by_name['user_id']._serialized_options = b'\372B\004r\002\020\001'
  _CALLPARTICIPANTTIMELINE.fields_by_name['session_id']._options = None
  _CALLPARTICIPANTTIMELINE.fields_by_name['session_id']._serialized_options = b'\372B\004r\002\020\001'
  _MEDIATYPE._serialized_start=1212
  _MEDIATYPE._serialized_end=1295
  _MEDIASTATECHANGE._serialized_start=1297
  _MEDIASTATECHANGE._serialized_end=1413
  _MEDIADIRECTION._serialized_start=1415
  _MEDIADIRECTION._serialized_end=1519
  _MEDIASTATECHANGEREASON._serialized_start=1522
  _MEDIASTATECHANGEREASON._serialized_end=1667
  _PARTICIPANTCONNECTED._serialized_start=164
  _PARTICIPANTCONNECTED._serialized_end=186
  _PARTICIPANTDISCONNECTED._serialized_start=188
  _PARTICIPANTDISCONNECTED._serialized_end=213
  _FREEZE._serialized_start=216
  _FREEZE._serialized_end=360
  _MEDIASTATECHANGED._serialized_start=363
  _MEDIASTATECHANGED._serialized_end=658
  _TELEMETRYEVENT._serialized_start=661
  _TELEMETRYEVENT._serialized_end=1061
  _CALLPARTICIPANTTIMELINE._serialized_start=1064
  _CALLPARTICIPANTTIMELINE._serialized_end=1210
# @@protoc_insertion_point(module_scope)
