"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _E:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_E.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNSPECIFIED: _E.ValueType  # 0
    """Error code is not specified"""
    AUTH_TOKEN_INVALID: _E.ValueType  # 1001
    """10xx - auth token errors

    Authentication token is invalid. This code is returned if none of specific error codes match
    """
    AUTH_TOKEN_NOT_VALID_YET: _E.ValueType  # 1002
    """Authentication token is not valid yet (`nbf` claim)"""
    AUTH_TOKEN_USED_BEFORE_ISSUE: _E.ValueType  # 1003
    """Authentication token is used before its issue date (`iat` claim)"""
    AUTH_TOKEN_EXPIRED: _E.ValueType  # 1004
    """Authentication token is expired (`exp` claim)"""
    AUTH_TOKEN_INVALID_SIGNATURE: _E.ValueType  # 1005
    """Authentication token has invalid signature"""
    API_KEY_NOT_PROVIDED: _E.ValueType  # 1101
    """11xx - API key errors

    API key is not provided
    """
    API_KEY_IS_UNKNOWN: _E.ValueType  # 1102
    """Unknown API key is provided"""
    PERMISSION_DENIED: _E.ValueType  # 1201
    """12xx - Permission errors

    Permission was denied
    """
    REQUEST_VALIDATION_FAILED: _E.ValueType  # 1301
    """13xx - validation errors

    Request validation failed
    """
    CALL_TYPE_NOT_FOUND: _E.ValueType  # 1401
    """14xx - Call type errors

    CallType was not found
    """
    CALL_TYPE_ALREADY_EXISTS: _E.ValueType  # 1403
    """RoomType already exists"""
    CALL_NOT_FOUND: _E.ValueType  # 1501
    """15xx - Call errors"""
    CALL_ALREADY_EXISTS: _E.ValueType  # 1502
    PUSH_PROVIDER_NOT_FOUND: _E.ValueType  # 1601
    """16xx - Push errors"""
    PUSH_DEVICE_NOT_FOUND: _E.ValueType  # 1602
    USER_NOT_FOUND: _E.ValueType  # 1701
    """17xx - User errors"""
    USER_ALREADY_EXISTS: _E.ValueType  # 1702
    SFU_NO_DATACENTERS_AVAILABLE: _E.ValueType  # 1801
    """18xx - SFU errors"""

class E(_E, metaclass=_EEnumTypeWrapper):
    """E defines all API error codes that client can receive
    Not to be confused with Twirp error codes. Most of API errors will produce `invalid_argument` Twirp error,
    but some are mapped to more specific ones like `permission_denied` or `not_found`.
    Keep the distance of `100` between error domains, so more errors can be added in the future.
    Do not use `xxx0` codes
    Do not prefix const values with  in this enum. This proto package only contains one enum which guarantees lack of name collision.
    When the prefix is used, Go generator creates consts with E_ERROR_* which we want to avoid here
    protolint:disable:next ENUM_FIELD_NAMES_PREFIX
    """

UNSPECIFIED: E.ValueType  # 0
"""Error code is not specified"""
AUTH_TOKEN_INVALID: E.ValueType  # 1001
"""10xx - auth token errors

Authentication token is invalid. This code is returned if none of specific error codes match
"""
AUTH_TOKEN_NOT_VALID_YET: E.ValueType  # 1002
"""Authentication token is not valid yet (`nbf` claim)"""
AUTH_TOKEN_USED_BEFORE_ISSUE: E.ValueType  # 1003
"""Authentication token is used before its issue date (`iat` claim)"""
AUTH_TOKEN_EXPIRED: E.ValueType  # 1004
"""Authentication token is expired (`exp` claim)"""
AUTH_TOKEN_INVALID_SIGNATURE: E.ValueType  # 1005
"""Authentication token has invalid signature"""
API_KEY_NOT_PROVIDED: E.ValueType  # 1101
"""11xx - API key errors

API key is not provided
"""
API_KEY_IS_UNKNOWN: E.ValueType  # 1102
"""Unknown API key is provided"""
PERMISSION_DENIED: E.ValueType  # 1201
"""12xx - Permission errors

Permission was denied
"""
REQUEST_VALIDATION_FAILED: E.ValueType  # 1301
"""13xx - validation errors

Request validation failed
"""
CALL_TYPE_NOT_FOUND: E.ValueType  # 1401
"""14xx - Call type errors

CallType was not found
"""
CALL_TYPE_ALREADY_EXISTS: E.ValueType  # 1403
"""RoomType already exists"""
CALL_NOT_FOUND: E.ValueType  # 1501
"""15xx - Call errors"""
CALL_ALREADY_EXISTS: E.ValueType  # 1502
PUSH_PROVIDER_NOT_FOUND: E.ValueType  # 1601
"""16xx - Push errors"""
PUSH_DEVICE_NOT_FOUND: E.ValueType  # 1602
USER_NOT_FOUND: E.ValueType  # 1701
"""17xx - User errors"""
USER_ALREADY_EXISTS: E.ValueType  # 1702
SFU_NO_DATACENTERS_AVAILABLE: E.ValueType  # 1801
"""18xx - SFU errors"""
global___E = E
