"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class App(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    WEBHOOK_FIELD_NUMBER: builtins.int
    id: builtins.int
    @property
    def webhook(self) -> global___WebhookSettings: ...
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        webhook: global___WebhookSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["webhook", b"webhook"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "webhook", b"webhook"]) -> None: ...

global___App = App

class WebhookSettings(google.protobuf.message.Message):
    """Keep in sync with stream.config.webhook.AppSettings"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_FIELD_NUMBER: builtins.int
    SQS_FIELD_NUMBER: builtins.int
    @property
    def http(self) -> global___HttpWebhook: ...
    @property
    def sqs(self) -> global___SqsWebhook: ...
    def __init__(
        self,
        *,
        http: global___HttpWebhook | None = ...,
        sqs: global___SqsWebhook | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["http", b"http", "sqs", b"sqs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["http", b"http", "sqs", b"sqs"]) -> None: ...

global___WebhookSettings = WebhookSettings

class HttpWebhook(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___HttpWebhook = HttpWebhook

class SqsWebhook(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    url: builtins.str
    key: builtins.str
    secret: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        key: builtins.str = ...,
        secret: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "secret", b"secret", "url", b"url"]) -> None: ...

global___SqsWebhook = SqsWebhook
