# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/server_v1_rpc/server_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from video.coordinator.app_v1 import app_pb2 as video_dot_coordinator_dot_app__v1_dot_app__pb2
from video.coordinator.broadcast_v1 import broadcast_pb2 as video_dot_coordinator_dot_broadcast__v1_dot_broadcast__pb2
from video.coordinator.call_v1 import call_pb2 as video_dot_coordinator_dot_call__v1_dot_call__pb2
from video.coordinator.push_v1 import push_pb2 as video_dot_coordinator_dot_push__v1_dot_push__pb2
from video.coordinator.recording_v1 import recording_pb2 as video_dot_coordinator_dot_recording__v1_dot_recording__pb2
from video.coordinator.server_v1_rpc import envelopes_pb2 as video_dot_coordinator_dot_server__v1__rpc_dot_envelopes__pb2
from video.coordinator.stat_v1 import stat_pb2 as video_dot_coordinator_dot_stat__v1_dot_stat__pb2
from video.coordinator.user_v1 import user_pb2 as video_dot_coordinator_dot_user__v1_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0video/coordinator/server_v1_rpc/server_rpc.proto\x12&stream.video.coordinator.server_v1_rpc\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\"video/coordinator/app_v1/app.proto\x1a.video/coordinator/broadcast_v1/broadcast.proto\x1a$video/coordinator/call_v1/call.proto\x1a$video/coordinator/push_v1/push.proto\x1a.video/coordinator/recording_v1/recording.proto\x1a/video/coordinator/server_v1_rpc/envelopes.proto\x1a$video/coordinator/stat_v1/stat.proto\x1a$video/coordinator/user_v1/user.proto\"\x0f\n\rGetAppRequest\"C\n\x0eGetAppResponse\x12\x31\n\x03\x61pp\x18\x01 \x01(\x0b\x32$.stream.video.coordinator.app_v1.App\"U\n\x10UpdateAppRequest\x12\x41\n\x07webhook\x18\x01 \x01(\x0b\x32\x30.stream.video.coordinator.app_v1.WebhookSettings\"F\n\x11UpdateAppResponse\x12\x31\n\x03\x61pp\x18\x01 \x01(\x0b\x32$.stream.video.coordinator.app_v1.App\"\xc8\x02\n\x11PushProviderInput\x12\n\n\x02id\x18\x01 \x01(\t\x12?\n\x03\x61pn\x18\x02 \x01(\x0b\x32\x30.stream.video.coordinator.push_v1.ApnCredentialsH\x00\x12I\n\x08\x66irebase\x18\x03 \x01(\x0b\x32\x35.stream.video.coordinator.push_v1.FirebaseCredentialsH\x00\x12\x45\n\x06huawei\x18\x04 \x01(\x0b\x32\x33.stream.video.coordinator.push_v1.HuaweiCredentialsH\x00\x12\x45\n\x06xiaomi\x18\x05 \x01(\x0b\x32\x33.stream.video.coordinator.push_v1.XiaomiCredentialsH\x00\x42\r\n\x0b\x63redentials\"e\n\x19\x43reatePushProviderRequest\x12H\n\x05input\x18\x01 \x01(\x0b\x32\x39.stream.video.coordinator.server_v1_rpc.PushProviderInput\"^\n\x1a\x43reatePushProviderResponse\x12@\n\x08provider\x18\x01 \x01(\x0b\x32..stream.video.coordinator.push_v1.PushProvider\"$\n\x16GetPushProviderRequest\x12\n\n\x02id\x18\x01 \x01(\t\"[\n\x17GetPushProviderResponse\x12@\n\x08provider\x18\x01 \x01(\x0b\x32..stream.video.coordinator.push_v1.PushProvider\"\x1b\n\x19QueryPushProvidersRequest\"_\n\x1aQueryPushProvidersResponse\x12\x41\n\tproviders\x18\x01 \x03(\x0b\x32..stream.video.coordinator.push_v1.PushProvider\"e\n\x19UpdatePushProviderRequest\x12H\n\x05input\x18\x01 \x01(\x0b\x32\x39.stream.video.coordinator.server_v1_rpc.PushProviderInput\"^\n\x1aUpdatePushProviderResponse\x12@\n\x08provider\x18\x01 \x01(\x0b\x32..stream.video.coordinator.push_v1.PushProvider\"\'\n\x19\x44\x65letePushProviderRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x1c\n\x1a\x44\x65letePushProviderResponse\"%\n\x15\x44\x65leteCallTypeRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteCallTypeResponse\"e\n\x15\x43reateCallTypeRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\x07options\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallOptions\"W\n\x16\x43reateCallTypeResponse\x12=\n\tcall_type\x18\x01 \x01(\x0b\x32*.stream.video.coordinator.call_v1.CallType\"\"\n\x12GetCallTypeRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"T\n\x13GetCallTypeResponse\x12=\n\tcall_type\x18\x01 \x01(\x0b\x32*.stream.video.coordinator.call_v1.CallType\"\x17\n\x15QueryCallTypesRequest\"X\n\x16QueryCallTypesResponse\x12>\n\ncall_types\x18\x01 \x03(\x0b\x32*.stream.video.coordinator.call_v1.CallType\"e\n\x15UpdateCallTypeRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\x07options\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallOptions\"W\n\x16UpdateCallTypeResponse\x12=\n\tcall_type\x18\x01 \x01(\x0b\x32*.stream.video.coordinator.call_v1.CallType\"\xab\x02\n\x11\x43reateCallRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0b\x63ustom_json\x18\x03 \x01(\x0c\x12\x17\n\x0fparticipant_ids\x18\x04 \x03(\t\x12\x31\n\rhls_broadcast\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12@\n\x04rtmp\x18\x07 \x01(\x0b\x32\x32.stream.video.coordinator.broadcast_v1.RTMPOptions\x12-\n\trecording\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06notify\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"r\n\x11\x43reateUserRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05teams\x18\x02 \x03(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\x12\x13\n\x0b\x63ustom_json\x18\x04 \x01(\x0c\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x11\n\timage_url\x18\x06 \x01(\t\"{\n\x1a\x43reateOrUpdateUsersRequest\x12H\n\x05users\x18\x01 \x03(\x0b\x32\x39.stream.video.coordinator.server_v1_rpc.CreateUserRequest\x12\x13\n\x0b\x66ull_update\x18\x02 \x01(\x08\"T\n\x1b\x43reateOrUpdateUsersResponse\x12\x35\n\x05users\x18\x01 \x03(\x0b\x32&.stream.video.coordinator.user_v1.User\"W\n\x11\x44\x65leteUserRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1b\n\x13\x64\x65lete_call_history\x18\x02 \x01(\x08\x12\x19\n\x11\x64\x65lete_recordings\x18\x03 \x01(\x08\"\x1f\n\x11\x45xportUserRequest\x12\n\n\x02id\x18\x01 \x01(\t\"e\n\x12\x45xportUserResponse\x12O\n\x0b\x65xport_user\x18\x01 \x01(\x0b\x32:.stream.video.coordinator.server_v1_rpc.ExportUserEnvelope\" \n\x12\x44\x65leteUserResponse\x12\n\n\x02id\x18\x01 \x01(\t\"J\n\x12\x43reateUserResponse\x12\x34\n\x04user\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.user_v1.User\"5\n\x0eUserCapability\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\x94\x01\n\x15StartBroadcastRequest\x12\x0f\n\x07\x63\x61ll_id\x18\x01 \x01(\t\x12\x11\n\tcall_type\x18\x02 \x01(\t\x12\x15\n\rhls_broadcast\x18\x03 \x01(\x08\x12@\n\x04rtmp\x18\x05 \x01(\x0b\x32\x32.stream.video.coordinator.broadcast_v1.RTMPOptions\"]\n\x16StartBroadcastResponse\x12\x43\n\tbroadcast\x18\x01 \x01(\x0b\x32\x30.stream.video.coordinator.broadcast_v1.Broadcast\"\x16\n\x14StopBroadcastRequest\"\x17\n\x15StopBroadcastResponse\"\x15\n\x13StoreLatencyRequest\"\x16\n\x14StoreLatencyResponse\";\n\x15StartRecordingRequest\x12\x11\n\tcall_type\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61ll_id\x18\x02 \x01(\t\"\x18\n\x16StartRecordingResponse\":\n\x14StopRecordingRequest\x12\x11\n\tcall_type\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61ll_id\x18\x02 \x01(\t\",\n\x15StopRecordingResponse\x12\x13\n\x0bs3_file_url\x18\x01 \x01(\t\"\x16\n\x14GetRecordingsRequest\"]\n\x15GetRecordingsResponse\x12\x44\n\nrecordings\x18\x01 \x03(\x0b\x32\x30.stream.video.coordinator.recording_v1.Recording\"\x18\n\x16\x44\x65leteRecordingRequest\"\x19\n\x17\x44\x65leteRecordingResponse\"\x92\x01\n\x1eQueryCallTimelineEventsRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12+\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x05since\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xf6\x01\n\x1fQueryCallTimelineEventsResponse\x12)\n\x05start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04next\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12U\n\x12participant_events\x18\x04 \x03(\x0b\x32\x39.stream.video.coordinator.stat_v1.CallParticipantTimeline2\x8a\x19\n\tServerRPC\x12w\n\x06GetApp\x12\x35.stream.video.coordinator.server_v1_rpc.GetAppRequest\x1a\x36.stream.video.coordinator.server_v1_rpc.GetAppResponse\x12\x80\x01\n\tUpdateApp\x12\x38.stream.video.coordinator.server_v1_rpc.UpdateAppRequest\x1a\x39.stream.video.coordinator.server_v1_rpc.UpdateAppResponse\x12\x8f\x01\n\x0e\x43reateCallType\x12=.stream.video.coordinator.server_v1_rpc.CreateCallTypeRequest\x1a>.stream.video.coordinator.server_v1_rpc.CreateCallTypeResponse\x12\x86\x01\n\x0bGetCallType\x12:.stream.video.coordinator.server_v1_rpc.GetCallTypeRequest\x1a;.stream.video.coordinator.server_v1_rpc.GetCallTypeResponse\x12\x8f\x01\n\x0eQueryCallTypes\x12=.stream.video.coordinator.server_v1_rpc.QueryCallTypesRequest\x1a>.stream.video.coordinator.server_v1_rpc.QueryCallTypesResponse\x12\x8f\x01\n\x0eUpdateCallType\x12=.stream.video.coordinator.server_v1_rpc.UpdateCallTypeRequest\x1a>.stream.video.coordinator.server_v1_rpc.UpdateCallTypeResponse\x12\x8f\x01\n\x0e\x44\x65leteCallType\x12=.stream.video.coordinator.server_v1_rpc.DeleteCallTypeRequest\x1a>.stream.video.coordinator.server_v1_rpc.DeleteCallTypeResponse\x12\x9b\x01\n\x12\x43reatePushProvider\x12\x41.stream.video.coordinator.server_v1_rpc.CreatePushProviderRequest\x1a\x42.stream.video.coordinator.server_v1_rpc.CreatePushProviderResponse\x12\x92\x01\n\x0fGetPushProvider\x12>.stream.video.coordinator.server_v1_rpc.GetPushProviderRequest\x1a?.stream.video.coordinator.server_v1_rpc.GetPushProviderResponse\x12\x9b\x01\n\x12QueryPushProviders\x12\x41.stream.video.coordinator.server_v1_rpc.QueryPushProvidersRequest\x1a\x42.stream.video.coordinator.server_v1_rpc.QueryPushProvidersResponse\x12\x9b\x01\n\x12UpdatePushProvider\x12\x41.stream.video.coordinator.server_v1_rpc.UpdatePushProviderRequest\x1a\x42.stream.video.coordinator.server_v1_rpc.UpdatePushProviderResponse\x12\x9b\x01\n\x12\x44\x65letePushProvider\x12\x41.stream.video.coordinator.server_v1_rpc.DeletePushProviderRequest\x1a\x42.stream.video.coordinator.server_v1_rpc.DeletePushProviderResponse\x12\x8f\x01\n\x0eStartBroadcast\x12=.stream.video.coordinator.server_v1_rpc.StartBroadcastRequest\x1a>.stream.video.coordinator.server_v1_rpc.StartBroadcastResponse\x12\x8c\x01\n\rStopBroadcast\x12<.stream.video.coordinator.server_v1_rpc.StopBroadcastRequest\x1a=.stream.video.coordinator.server_v1_rpc.StopBroadcastResponse\x12\x8f\x01\n\x0eStartRecording\x12=.stream.video.coordinator.server_v1_rpc.StartRecordingRequest\x1a>.stream.video.coordinator.server_v1_rpc.StartRecordingResponse\x12\x8c\x01\n\rStopRecording\x12<.stream.video.coordinator.server_v1_rpc.StopRecordingRequest\x1a=.stream.video.coordinator.server_v1_rpc.StopRecordingResponse\x12\x8c\x01\n\rGetRecordings\x12<.stream.video.coordinator.server_v1_rpc.GetRecordingsRequest\x1a=.stream.video.coordinator.server_v1_rpc.GetRecordingsResponse\x12\x92\x01\n\x0f\x44\x65leteRecording\x12>.stream.video.coordinator.server_v1_rpc.DeleteRecordingRequest\x1a?.stream.video.coordinator.server_v1_rpc.DeleteRecordingResponse\x12\xaa\x01\n\x17QueryCallTimelineEvents\x12\x46.stream.video.coordinator.server_v1_rpc.QueryCallTimelineEventsRequest\x1aG.stream.video.coordinator.server_v1_rpc.QueryCallTimelineEventsResponse\x12\x83\x01\n\nCreateUser\x12\x39.stream.video.coordinator.server_v1_rpc.CreateUserRequest\x1a:.stream.video.coordinator.server_v1_rpc.CreateUserResponse\x12\x83\x01\n\nDeleteUser\x12\x39.stream.video.coordinator.server_v1_rpc.DeleteUserRequest\x1a:.stream.video.coordinator.server_v1_rpc.DeleteUserResponse\x12\x83\x01\n\nExportUser\x12\x39.stream.video.coordinator.server_v1_rpc.ExportUserRequest\x1a:.stream.video.coordinator.server_v1_rpc.ExportUserResponseB\x0fZ\rserver_v1_rpcb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.server_v1_rpc.server_rpc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\rserver_v1_rpc'
  _GETAPPREQUEST._serialized_start=522
  _GETAPPREQUEST._serialized_end=537
  _GETAPPRESPONSE._serialized_start=539
  _GETAPPRESPONSE._serialized_end=606
  _UPDATEAPPREQUEST._serialized_start=608
  _UPDATEAPPREQUEST._serialized_end=693
  _UPDATEAPPRESPONSE._serialized_start=695
  _UPDATEAPPRESPONSE._serialized_end=765
  _PUSHPROVIDERINPUT._serialized_start=768
  _PUSHPROVIDERINPUT._serialized_end=1096
  _CREATEPUSHPROVIDERREQUEST._serialized_start=1098
  _CREATEPUSHPROVIDERREQUEST._serialized_end=1199
  _CREATEPUSHPROVIDERRESPONSE._serialized_start=1201
  _CREATEPUSHPROVIDERRESPONSE._serialized_end=1295
  _GETPUSHPROVIDERREQUEST._serialized_start=1297
  _GETPUSHPROVIDERREQUEST._serialized_end=1333
  _GETPUSHPROVIDERRESPONSE._serialized_start=1335
  _GETPUSHPROVIDERRESPONSE._serialized_end=1426
  _QUERYPUSHPROVIDERSREQUEST._serialized_start=1428
  _QUERYPUSHPROVIDERSREQUEST._serialized_end=1455
  _QUERYPUSHPROVIDERSRESPONSE._serialized_start=1457
  _QUERYPUSHPROVIDERSRESPONSE._serialized_end=1552
  _UPDATEPUSHPROVIDERREQUEST._serialized_start=1554
  _UPDATEPUSHPROVIDERREQUEST._serialized_end=1655
  _UPDATEPUSHPROVIDERRESPONSE._serialized_start=1657
  _UPDATEPUSHPROVIDERRESPONSE._serialized_end=1751
  _DELETEPUSHPROVIDERREQUEST._serialized_start=1753
  _DELETEPUSHPROVIDERREQUEST._serialized_end=1792
  _DELETEPUSHPROVIDERRESPONSE._serialized_start=1794
  _DELETEPUSHPROVIDERRESPONSE._serialized_end=1822
  _DELETECALLTYPEREQUEST._serialized_start=1824
  _DELETECALLTYPEREQUEST._serialized_end=1861
  _DELETECALLTYPERESPONSE._serialized_start=1863
  _DELETECALLTYPERESPONSE._serialized_end=1887
  _CREATECALLTYPEREQUEST._serialized_start=1889
  _CREATECALLTYPEREQUEST._serialized_end=1990
  _CREATECALLTYPERESPONSE._serialized_start=1992
  _CREATECALLTYPERESPONSE._serialized_end=2079
  _GETCALLTYPEREQUEST._serialized_start=2081
  _GETCALLTYPEREQUEST._serialized_end=2115
  _GETCALLTYPERESPONSE._serialized_start=2117
  _GETCALLTYPERESPONSE._serialized_end=2201
  _QUERYCALLTYPESREQUEST._serialized_start=2203
  _QUERYCALLTYPESREQUEST._serialized_end=2226
  _QUERYCALLTYPESRESPONSE._serialized_start=2228
  _QUERYCALLTYPESRESPONSE._serialized_end=2316
  _UPDATECALLTYPEREQUEST._serialized_start=2318
  _UPDATECALLTYPEREQUEST._serialized_end=2419
  _UPDATECALLTYPERESPONSE._serialized_start=2421
  _UPDATECALLTYPERESPONSE._serialized_end=2508
  _CREATECALLREQUEST._serialized_start=2511
  _CREATECALLREQUEST._serialized_end=2810
  _CREATEUSERREQUEST._serialized_start=2812
  _CREATEUSERREQUEST._serialized_end=2926
  _CREATEORUPDATEUSERSREQUEST._serialized_start=2928
  _CREATEORUPDATEUSERSREQUEST._serialized_end=3051
  _CREATEORUPDATEUSERSRESPONSE._serialized_start=3053
  _CREATEORUPDATEUSERSRESPONSE._serialized_end=3137
  _DELETEUSERREQUEST._serialized_start=3139
  _DELETEUSERREQUEST._serialized_end=3226
  _EXPORTUSERREQUEST._serialized_start=3228
  _EXPORTUSERREQUEST._serialized_end=3259
  _EXPORTUSERRESPONSE._serialized_start=3261
  _EXPORTUSERRESPONSE._serialized_end=3362
  _DELETEUSERRESPONSE._serialized_start=3364
  _DELETEUSERRESPONSE._serialized_end=3396
  _CREATEUSERRESPONSE._serialized_start=3398
  _CREATEUSERRESPONSE._serialized_end=3472
  _USERCAPABILITY._serialized_start=3474
  _USERCAPABILITY._serialized_end=3527
  _STARTBROADCASTREQUEST._serialized_start=3530
  _STARTBROADCASTREQUEST._serialized_end=3678
  _STARTBROADCASTRESPONSE._serialized_start=3680
  _STARTBROADCASTRESPONSE._serialized_end=3773
  _STOPBROADCASTREQUEST._serialized_start=3775
  _STOPBROADCASTREQUEST._serialized_end=3797
  _STOPBROADCASTRESPONSE._serialized_start=3799
  _STOPBROADCASTRESPONSE._serialized_end=3822
  _STORELATENCYREQUEST._serialized_start=3824
  _STORELATENCYREQUEST._serialized_end=3845
  _STORELATENCYRESPONSE._serialized_start=3847
  _STORELATENCYRESPONSE._serialized_end=3869
  _STARTRECORDINGREQUEST._serialized_start=3871
  _STARTRECORDINGREQUEST._serialized_end=3930
  _STARTRECORDINGRESPONSE._serialized_start=3932
  _STARTRECORDINGRESPONSE._serialized_end=3956
  _STOPRECORDINGREQUEST._serialized_start=3958
  _STOPRECORDINGREQUEST._serialized_end=4016
  _STOPRECORDINGRESPONSE._serialized_start=4018
  _STOPRECORDINGRESPONSE._serialized_end=4062
  _GETRECORDINGSREQUEST._serialized_start=4064
  _GETRECORDINGSREQUEST._serialized_end=4086
  _GETRECORDINGSRESPONSE._serialized_start=4088
  _GETRECORDINGSRESPONSE._serialized_end=4181
  _DELETERECORDINGREQUEST._serialized_start=4183
  _DELETERECORDINGREQUEST._serialized_end=4207
  _DELETERECORDINGRESPONSE._serialized_start=4209
  _DELETERECORDINGRESPONSE._serialized_end=4234
  _QUERYCALLTIMELINEEVENTSREQUEST._serialized_start=4237
  _QUERYCALLTIMELINEEVENTSREQUEST._serialized_end=4383
  _QUERYCALLTIMELINEEVENTSRESPONSE._serialized_start=4386
  _QUERYCALLTIMELINEEVENTSRESPONSE._serialized_end=4632
  _SERVERRPC._serialized_start=4635
  _SERVERRPC._serialized_end=7845
# @@protoc_insertion_point(module_scope)
