# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/sfu/remote_control_rpc/remote_control_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from video.sfu.models import models_pb2 as video_dot_sfu_dot_models_dot_models__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4video/sfu/remote_control_rpc/remote_control_v1.proto\x12\x1fstream.video.sfu.remote_control\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dvideo/sfu/models/models.proto\"\x85\x01\n\x0fKickUserRequest\x12\x0e\n\x06\x61pp_pk\x18\x01 \x01(\x03\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61ll_ids\x18\x03 \x03(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\x12.\n\nnot_before\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x12\n\x10KickUserResponse\"\x8c\x01\n\x16InvalidateTokenRequest\x12\x0e\n\x06\x61pp_pk\x18\x01 \x01(\x03\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61ll_ids\x18\x03 \x03(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\x12.\n\nnot_before\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x19\n\x17InvalidateTokenResponse\"e\n\x17MuteParticipantsRequest\x12\x0e\n\x06\x61pp_pk\x18\x01 \x01(\x03\x12:\n\x0cparticipants\x18\x02 \x03(\x0b\x32$.stream.video.sfu.models.Participant\"\x9f\x01\n\x14MuteParticipantInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\nsession_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nmute_audio\x18\x03 \x01(\x08H\x01\x88\x01\x01\x12\x17\n\nmute_video\x18\x04 \x01(\x08H\x02\x88\x01\x01\x42\r\n\x0b_session_idB\r\n\x0b_mute_audioB\r\n\x0b_mute_video\"\x1a\n\x18MuteParticipantsResponse\"@\n\x0eGetCallRequest\x12\x0e\n\x06\x61pp_pk\x18\x01 \x01(\x03\x12\n\n\x02id\x18\x02 \x01(\t\x12\x12\n\nwith_state\x18\x03 \x01(\x08\"q\n\x0fGetCallResponse\x12+\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x1d.stream.video.sfu.models.Call\x12\x31\n\x05state\x18\x02 \x01(\x0b\x32\".stream.video.sfu.models.CallState\"p\n\x11\x43reateCallRequest\x12\x0e\n\x06\x61pp_pk\x18\x01 \x01(\x03\x12\n\n\x02id\x18\x02 \x01(\t\x12 \n\x18\x63\x61scading_sfus_hostnames\x18\x03 \x03(\t\x12\x1d\n\x15gossip_rpc_auth_token\x18\x04 \x01(\t\"A\n\x12\x43reateCallResponse\x12+\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x1d.stream.video.sfu.models.Call\"=\n\x0e\x45ndCallRequest\x12\x0e\n\x06\x61pp_pk\x18\x01 \x01(\x03\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\">\n\x0f\x45ndCallResponse\x12+\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x1d.stream.video.sfu.models.Call2\xe0\x04\n\x10RemoteControlRPC\x12o\n\x08KickUser\x12\x30.stream.video.sfu.remote_control.KickUserRequest\x1a\x31.stream.video.sfu.remote_control.KickUserResponse\x12\x87\x01\n\x10MuteParticipants\x12\x38.stream.video.sfu.remote_control.MuteParticipantsRequest\x1a\x39.stream.video.sfu.remote_control.MuteParticipantsResponse\x12l\n\x07GetCall\x12/.stream.video.sfu.remote_control.GetCallRequest\x1a\x30.stream.video.sfu.remote_control.GetCallResponse\x12u\n\nCreateCall\x12\x32.stream.video.sfu.remote_control.CreateCallRequest\x1a\x33.stream.video.sfu.remote_control.CreateCallResponse\x12l\n\x07\x45ndCall\x12/.stream.video.sfu.remote_control.EndCallRequest\x1a\x30.stream.video.sfu.remote_control.EndCallResponseB\x14Z\x12remote_control_rpcb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.sfu.remote_control_rpc.remote_control_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\022remote_control_rpc'
  _KICKUSERREQUEST._serialized_start=154
  _KICKUSERREQUEST._serialized_end=287
  _KICKUSERRESPONSE._serialized_start=289
  _KICKUSERRESPONSE._serialized_end=307
  _INVALIDATETOKENREQUEST._serialized_start=310
  _INVALIDATETOKENREQUEST._serialized_end=450
  _INVALIDATETOKENRESPONSE._serialized_start=452
  _INVALIDATETOKENRESPONSE._serialized_end=477
  _MUTEPARTICIPANTSREQUEST._serialized_start=479
  _MUTEPARTICIPANTSREQUEST._serialized_end=580
  _MUTEPARTICIPANTINPUT._serialized_start=583
  _MUTEPARTICIPANTINPUT._serialized_end=742
  _MUTEPARTICIPANTSRESPONSE._serialized_start=744
  _MUTEPARTICIPANTSRESPONSE._serialized_end=770
  _GETCALLREQUEST._serialized_start=772
  _GETCALLREQUEST._serialized_end=836
  _GETCALLRESPONSE._serialized_start=838
  _GETCALLRESPONSE._serialized_end=951
  _CREATECALLREQUEST._serialized_start=953
  _CREATECALLREQUEST._serialized_end=1065
  _CREATECALLRESPONSE._serialized_start=1067
  _CREATECALLRESPONSE._serialized_end=1132
  _ENDCALLREQUEST._serialized_start=1134
  _ENDCALLREQUEST._serialized_end=1195
  _ENDCALLRESPONSE._serialized_start=1197
  _ENDCALLRESPONSE._serialized_end=1259
  _REMOTECONTROLRPC._serialized_start=1262
  _REMOTECONTROLRPC._serialized_end=1870
# @@protoc_insertion_point(module_scope)
