# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/edge_v1/edge.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$video/coordinator/edge_v1/edge.proto\x12 stream.video.coordinator.edge_v1\x1a\x17validate/validate.proto\"\xaf\x01\n\x0b\x43redentials\x12\x46\n\x06server\x18\x01 \x01(\x0b\x32,.stream.video.coordinator.edge_v1.EdgeServerB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x16\n\x05token\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12@\n\x0bice_servers\x18\x03 \x03(\x0b\x32+.stream.video.coordinator.edge_v1.ICEServer\"\xd4\x01\n\x13LatencyMeasurements\x12]\n\x0cmeasurements\x18\x01 \x03(\x0b\x32G.stream.video.coordinator.edge_v1.LatencyMeasurements.MeasurementsEntry\x1a^\n\x11MeasurementsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).stream.video.coordinator.edge_v1.Latency:\x02\x38\x01\"\'\n\x07Latency\x12\x1c\n\x14measurements_seconds\x18\x01 \x03(\x01\"(\n\x0b\x43oordinates\x12\x0b\n\x03lat\x18\x01 \x01(\x02\x12\x0c\n\x04long\x18\x02 \x01(\x02\"\x7f\n\x04\x45\x64ge\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1c\n\x0blatency_url\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x42\n\x0b\x63oordinates\x18\x03 \x01(\x0b\x32-.stream.video.coordinator.edge_v1.Coordinates\"=\n\tICEServer\x12\x0c\n\x04urls\x18\x01 \x03(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\",\n\nEdgeServer\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tedge_name\x18\x02 \x01(\tB1B\x06\x45\x64geV1P\x01Z\x07\x65\x64ge_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.edge_v1.edge_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\006EdgeV1P\001Z\007edge_v1\252\002\033Stream.Video.v1.Coordinator'
  _CREDENTIALS.fields_by_name['server']._options = None
  _CREDENTIALS.fields_by_name['server']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREDENTIALS.fields_by_name['token']._options = None
  _CREDENTIALS.fields_by_name['token']._serialized_options = b'\372B\004r\002\020\001'
  _LATENCYMEASUREMENTS_MEASUREMENTSENTRY._options = None
  _LATENCYMEASUREMENTS_MEASUREMENTSENTRY._serialized_options = b'8\001'
  _EDGE.fields_by_name['name']._options = None
  _EDGE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _EDGE.fields_by_name['latency_url']._options = None
  _EDGE.fields_by_name['latency_url']._serialized_options = b'\372B\004r\002\020\001'
  _CREDENTIALS._serialized_start=100
  _CREDENTIALS._serialized_end=275
  _LATENCYMEASUREMENTS._serialized_start=278
  _LATENCYMEASUREMENTS._serialized_end=490
  _LATENCYMEASUREMENTS_MEASUREMENTSENTRY._serialized_start=396
  _LATENCYMEASUREMENTS_MEASUREMENTSENTRY._serialized_end=490
  _LATENCY._serialized_start=492
  _LATENCY._serialized_end=531
  _COORDINATES._serialized_start=533
  _COORDINATES._serialized_end=573
  _EDGE._serialized_start=575
  _EDGE._serialized_end=702
  _ICESERVER._serialized_start=704
  _ICESERVER._serialized_end=765
  _EDGESERVER._serialized_start=767
  _EDGESERVER._serialized_end=811
# @@protoc_insertion_point(module_scope)
