# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/sfu/models/models.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvideo/sfu/models/models.proto\x12\x17stream.video.sfu.models\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"G\n\tCallState\x12:\n\x0cparticipants\x18\x01 \x03(\x0b\x32$.stream.video.sfu.models.Participant\"\xdb\x01\n\x04\x43\x61ll\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x1a\n\x12\x63reated_by_user_id\x18\x03 \x01(\t\x12\x14\n\x0chost_user_id\x18\x04 \x01(\t\x12\'\n\x06\x63ustom\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xb0\x02\n\x0bParticipant\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x1d.stream.video.sfu.models.User\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x0e\n\x06online\x18\x03 \x01(\x08\x12\'\n\x06\x63ustom\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05video\x18\x05 \x01(\x08\x12\r\n\x05\x61udio\x18\x06 \x01(\x08\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nsession_id\x18\t \x01(\t\x12\x1b\n\x13track_lookup_prefix\x18\n \x01(\t\"\xa1\x01\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05teams\x18\x02 \x03(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\x12\'\n\x06\x63ustom\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x11\n\timage_url\x18\x06 \x01(\t\x12\x12\n\ncreated_at\x18\x07 \x01(\t\x12\x12\n\nupdated_at\x18\x08 \x01(\t\"^\n\rStreamQuality\x12<\n\rvideo_quality\x18\x01 \x01(\x0e\x32%.stream.video.sfu.models.VideoQuality\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"/\n\x0eVideoDimension\x12\r\n\x05width\x18\x01 \x01(\r\x12\x0e\n\x06height\x18\x02 \x01(\r\"l\n\nVideoLayer\x12\x0b\n\x03rid\x18\x01 \x01(\t\x12@\n\x0fvideo_dimension\x18\x02 \x01(\x0b\x32\'.stream.video.sfu.models.VideoDimension\x12\x0f\n\x07\x62itrate\x18\x04 \x01(\r\"v\n\x12SimulcastCodecInfo\x12\x11\n\tmime_type\x18\x01 \x01(\t\x12\x0b\n\x03mid\x18\x02 \x01(\t\x12\x0b\n\x03\x63id\x18\x03 \x01(\t\x12\x33\n\x06layers\x18\x04 \x03(\x0b\x32#.stream.video.sfu.models.VideoLayer\"T\n\x05\x43odec\x12\x0c\n\x04mime\x18\x01 \x01(\t\x12\x11\n\tfmtp_line\x18\x02 \x01(\t\x12\x12\n\nclock_rate\x18\x03 \x01(\r\x12\x16\n\x0ehw_accelerated\x18\x04 \x01(\x08\"o\n\x0b\x41udioCodecs\x12/\n\x07\x65ncodes\x18\x01 \x03(\x0b\x32\x1e.stream.video.sfu.models.Codec\x12/\n\x07\x64\x65\x63odes\x18\x02 \x03(\x0b\x32\x1e.stream.video.sfu.models.Codec\"o\n\x0bVideoCodecs\x12/\n\x07\x65ncodes\x18\x01 \x03(\x0b\x32\x1e.stream.video.sfu.models.Codec\x12/\n\x07\x64\x65\x63odes\x18\x02 \x03(\x0b\x32\x1e.stream.video.sfu.models.Codec\"\xae\x01\n\rCodecSettings\x12\x33\n\x05\x61udio\x18\x01 \x01(\x0b\x32$.stream.video.sfu.models.AudioCodecs\x12\x33\n\x05video\x18\x02 \x01(\x0b\x32$.stream.video.sfu.models.VideoCodecs\x12\x33\n\x06layers\x18\x03 \x03(\x0b\x32#.stream.video.sfu.models.VideoLayer\"m\n\nICETrickle\x12\x34\n\tpeer_type\x18\x01 \x01(\x0e\x32!.stream.video.sfu.models.PeerType\x12\x15\n\rice_candidate\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\t*I\n\x08PeerType\x12#\n\x1fPEER_TYPE_PUBLISHER_UNSPECIFIED\x10\x00\x12\x18\n\x14PEER_TYPE_SUBSCRIBER\x10\x01*u\n\x11\x43onnectionQuality\x12&\n\"CONNECTION_QUALITY_BAD_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43ONNECTION_QUALITY_POOR\x10\x01\x12\x1b\n\x17\x43ONNECTION_QUALITY_GOOD\x10\x02*`\n\x0cVideoQuality\x12!\n\x1dVIDEO_QUALITY_LOW_UNSPECIFIED\x10\x00\x12\x15\n\x11VIDEO_QUALITY_MID\x10\x01\x12\x16\n\x12VIDEO_QUALITY_HIGH\x10\x02\x42\x31\x42\x0bSfuModelsV1P\x01Z\nsfu_models\xaa\x02\x13Stream.Video.v1.Sfub\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.sfu.models.models_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\013SfuModelsV1P\001Z\nsfu_models\252\002\023Stream.Video.v1.Sfu'
  _PEERTYPE._serialized_start=1862
  _PEERTYPE._serialized_end=1935
  _CONNECTIONQUALITY._serialized_start=1937
  _CONNECTIONQUALITY._serialized_end=2054
  _VIDEOQUALITY._serialized_start=2056
  _VIDEOQUALITY._serialized_end=2152
  _CALLSTATE._serialized_start=121
  _CALLSTATE._serialized_end=192
  _CALL._serialized_start=195
  _CALL._serialized_end=414
  _PARTICIPANT._serialized_start=417
  _PARTICIPANT._serialized_end=721
  _USER._serialized_start=724
  _USER._serialized_end=885
  _STREAMQUALITY._serialized_start=887
  _STREAMQUALITY._serialized_end=981
  _VIDEODIMENSION._serialized_start=983
  _VIDEODIMENSION._serialized_end=1030
  _VIDEOLAYER._serialized_start=1032
  _VIDEOLAYER._serialized_end=1140
  _SIMULCASTCODECINFO._serialized_start=1142
  _SIMULCASTCODECINFO._serialized_end=1260
  _CODEC._serialized_start=1262
  _CODEC._serialized_end=1346
  _AUDIOCODECS._serialized_start=1348
  _AUDIOCODECS._serialized_end=1459
  _VIDEOCODECS._serialized_start=1461
  _VIDEOCODECS._serialized_end=1572
  _CODECSETTINGS._serialized_start=1575
  _CODECSETTINGS._serialized_end=1749
  _ICETRICKLE._serialized_start=1751
  _ICETRICKLE._serialized_end=1860
# @@protoc_insertion_point(module_scope)
