# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/sfu/cascading_rpc/gossip.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$video/sfu/cascading_rpc/gossip.proto\x12\x17stream.video.sfu.gossip\"@\n\x0cSubscription\x12\x14\n\x0cpublisher_id\x18\x01 \x01(\t\x12\x0b\n\x03rid\x18\x02 \x01(\t\x12\r\n\x05\x63oded\x18\x03 \x01(\t\"\\\n\x0bParticipant\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12<\n\rsubscriptions\x18\x02 \x03(\x0b\x32%.stream.video.sfu.gossip.Subscription\"Y\n\tCallState\x12:\n\x0cparticipants\x18\x01 \x03(\x0b\x32$.stream.video.sfu.gossip.Participant\x12\x10\n\x08sequence\x18\x02 \x01(\x03\"\\\n\x0fJoinCallRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12\x37\n\x0blocal_state\x18\x02 \x01(\x0b\x32\".stream.video.sfu.gossip.CallState\"b\n\x10JoinCallResponse\x12\x15\n\rsfu_addresses\x18\x01 \x03(\t\x12\x37\n\x0blocal_state\x18\x02 \x01(\x0b\x32\".stream.video.sfu.gossip.CallState\"\x15\n\x13GetCallStateRequest\"O\n\x14GetCallStateResponse\x12\x37\n\x0blocal_state\x18\x01 \x01(\x0b\x32\".stream.video.sfu.gossip.CallState\"\x12\n\x10\x41udioMuteChanged\"\r\n\x0bHealthcheck\"\x12\n\x10VideoMuteChanged\"\x8f\x02\n\x10SendEventRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x03\x12<\n\x0chealth_check\x18\x03 \x01(\x0b\x32$.stream.video.sfu.gossip.HealthcheckH\x00\x12G\n\x12\x61udio_mute_changed\x18\x04 \x01(\x0b\x32).stream.video.sfu.gossip.AudioMuteChangedH\x00\x12G\n\x12video_mute_changed\x18\x05 \x01(\x0b\x32).stream.video.sfu.gossip.VideoMuteChangedH\x00\x42\x07\n\x05\x65vent\"\x13\n\x11SendEventResponse2\xbd\x02\n\tGossipRPC\x12_\n\x08JoinCall\x12(.stream.video.sfu.gossip.JoinCallRequest\x1a).stream.video.sfu.gossip.JoinCallResponse\x12\x62\n\tSendEvent\x12).stream.video.sfu.gossip.SendEventRequest\x1a*.stream.video.sfu.gossip.SendEventResponse\x12k\n\x0cGetCallState\x12,.stream.video.sfu.gossip.GetCallStateRequest\x1a-.stream.video.sfu.gossip.GetCallStateResponseB\x10Z\x0esfu_gossip_rpcb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.sfu.cascading_rpc.gossip_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\016sfu_gossip_rpc'
  _SUBSCRIPTION._serialized_start=65
  _SUBSCRIPTION._serialized_end=129
  _PARTICIPANT._serialized_start=131
  _PARTICIPANT._serialized_end=223
  _CALLSTATE._serialized_start=225
  _CALLSTATE._serialized_end=314
  _JOINCALLREQUEST._serialized_start=316
  _JOINCALLREQUEST._serialized_end=408
  _JOINCALLRESPONSE._serialized_start=410
  _JOINCALLRESPONSE._serialized_end=508
  _GETCALLSTATEREQUEST._serialized_start=510
  _GETCALLSTATEREQUEST._serialized_end=531
  _GETCALLSTATERESPONSE._serialized_start=533
  _GETCALLSTATERESPONSE._serialized_end=612
  _AUDIOMUTECHANGED._serialized_start=614
  _AUDIOMUTECHANGED._serialized_end=632
  _HEALTHCHECK._serialized_start=634
  _HEALTHCHECK._serialized_end=647
  _VIDEOMUTECHANGED._serialized_start=649
  _VIDEOMUTECHANGED._serialized_end=667
  _SENDEVENTREQUEST._serialized_start=670
  _SENDEVENTREQUEST._serialized_end=941
  _SENDEVENTRESPONSE._serialized_start=943
  _SENDEVENTRESPONSE._serialized_end=962
  _GOSSIPRPC._serialized_start=965
  _GOSSIPRPC._serialized_end=1282
# @@protoc_insertion_point(module_scope)
