"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import video.coordinator.call_v1.call_pb2
import video.coordinator.member_v1.member_pb2
import video.coordinator.recording_v1.recording_pb2
import video.coordinator.user_v1.user_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ExportUserEnvelope(google.protobuf.message.Message):
    """CallsEnvelope contains list of members and all related information to them
    Only used in response types that return list of members
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class MembersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> video.coordinator.member_v1.member_pb2.Member: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: video.coordinator.member_v1.member_pb2.Member | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    USER_FIELD_NUMBER: builtins.int
    CALLS_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    RECORDINGS_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> video.coordinator.user_v1.user_pb2.User: ...
    @property
    def calls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[video.coordinator.call_v1.call_pb2.Call]: ...
    @property
    def members(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, video.coordinator.member_v1.member_pb2.Member]:
        """Map of members indexed by Call.call_cid"""
    @property
    def recordings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[video.coordinator.recording_v1.recording_pb2.Recording]: ...
    def __init__(
        self,
        *,
        user: video.coordinator.user_v1.user_pb2.User | None = ...,
        calls: collections.abc.Iterable[video.coordinator.call_v1.call_pb2.Call] | None = ...,
        members: collections.abc.Mapping[builtins.str, video.coordinator.member_v1.member_pb2.Member] | None = ...,
        recordings: collections.abc.Iterable[video.coordinator.recording_v1.recording_pb2.Recording] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["calls", b"calls", "members", b"members", "recordings", b"recordings", "user", b"user"]) -> None: ...

global___ExportUserEnvelope = ExportUserEnvelope
