# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/event_v1/event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2
from video.coordinator.call_v1 import call_pb2 as video_dot_coordinator_dot_call__v1_dot_call__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&video/coordinator/event_v1/event.proto\x12!stream.video.coordinator.event_v1\x1a\x17validate/validate.proto\x1a$video/coordinator/call_v1/call.proto\"\xa1\x01\n\x10RecordingStarted\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xa1\x01\n\x10RecordingStopped\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\'\n\x0bUserUpdated\x12\x18\n\x07user_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xa1\x01\n\x10\x42roadcastStarted\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x9f\x01\n\x0e\x42roadcastEnded\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xb4\x01\n\x12\x43\x61llMembersCreated\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x0f\n\x07ringing\x18\x03 \x01(\x08\"\xa3\x01\n\x12\x43\x61llMembersUpdated\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xa3\x01\n\x12\x43\x61llMembersDeleted\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xad\x01\n\x0b\x43\x61llCreated\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x0f\n\x07ringing\x18\x03 \x01(\x08\"\x9c\x01\n\x0b\x43\x61llUpdated\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x9a\x01\n\tCallEnded\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x9c\x01\n\x0b\x43\x61llDeleted\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xbe\x01\n\x0c\x43\x61llAccepted\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1f\n\x0esender_user_id\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xbe\x01\n\x0c\x43\x61llRejected\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1f\n\x0esender_user_id\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xbf\x01\n\rCallCancelled\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1f\n\x0esender_user_id\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xe6\x01\n\nCallCustom\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1f\n\x0esender_user_id\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04type\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x11\n\tdata_json\x18\x05 \x01(\x0c\x42\x33\x42\x07\x45ventV1P\x01Z\x08\x65vent_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.event_v1.event_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\007EventV1P\001Z\010event_v1\252\002\033Stream.Video.v1.Coordinator'
  _RECORDINGSTARTED.fields_by_name['call']._options = None
  _RECORDINGSTARTED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RECORDINGSTARTED.fields_by_name['call_details']._options = None
  _RECORDINGSTARTED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RECORDINGSTOPPED.fields_by_name['call']._options = None
  _RECORDINGSTOPPED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RECORDINGSTOPPED.fields_by_name['call_details']._options = None
  _RECORDINGSTOPPED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _USERUPDATED.fields_by_name['user_id']._options = None
  _USERUPDATED.fields_by_name['user_id']._serialized_options = b'\372B\004r\002\020\001'
  _BROADCASTSTARTED.fields_by_name['call']._options = None
  _BROADCASTSTARTED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BROADCASTSTARTED.fields_by_name['call_details']._options = None
  _BROADCASTSTARTED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BROADCASTENDED.fields_by_name['call']._options = None
  _BROADCASTENDED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BROADCASTENDED.fields_by_name['call_details']._options = None
  _BROADCASTENDED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLMEMBERSCREATED.fields_by_name['call']._options = None
  _CALLMEMBERSCREATED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLMEMBERSCREATED.fields_by_name['call_details']._options = None
  _CALLMEMBERSCREATED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLMEMBERSUPDATED.fields_by_name['call']._options = None
  _CALLMEMBERSUPDATED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLMEMBERSUPDATED.fields_by_name['call_details']._options = None
  _CALLMEMBERSUPDATED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLMEMBERSDELETED.fields_by_name['call']._options = None
  _CALLMEMBERSDELETED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLMEMBERSDELETED.fields_by_name['call_details']._options = None
  _CALLMEMBERSDELETED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLCREATED.fields_by_name['call']._options = None
  _CALLCREATED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLCREATED.fields_by_name['call_details']._options = None
  _CALLCREATED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLUPDATED.fields_by_name['call']._options = None
  _CALLUPDATED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLUPDATED.fields_by_name['call_details']._options = None
  _CALLUPDATED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLENDED.fields_by_name['call']._options = None
  _CALLENDED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLENDED.fields_by_name['call_details']._options = None
  _CALLENDED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLDELETED.fields_by_name['call']._options = None
  _CALLDELETED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLDELETED.fields_by_name['call_details']._options = None
  _CALLDELETED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLACCEPTED.fields_by_name['call']._options = None
  _CALLACCEPTED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLACCEPTED.fields_by_name['call_details']._options = None
  _CALLACCEPTED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLACCEPTED.fields_by_name['sender_user_id']._options = None
  _CALLACCEPTED.fields_by_name['sender_user_id']._serialized_options = b'\372B\004r\002\020\001'
  _CALLREJECTED.fields_by_name['call']._options = None
  _CALLREJECTED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLREJECTED.fields_by_name['call_details']._options = None
  _CALLREJECTED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLREJECTED.fields_by_name['sender_user_id']._options = None
  _CALLREJECTED.fields_by_name['sender_user_id']._serialized_options = b'\372B\004r\002\020\001'
  _CALLCANCELLED.fields_by_name['call']._options = None
  _CALLCANCELLED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLCANCELLED.fields_by_name['call_details']._options = None
  _CALLCANCELLED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLCANCELLED.fields_by_name['sender_user_id']._options = None
  _CALLCANCELLED.fields_by_name['sender_user_id']._serialized_options = b'\372B\004r\002\020\001'
  _CALLCUSTOM.fields_by_name['call']._options = None
  _CALLCUSTOM.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLCUSTOM.fields_by_name['call_details']._options = None
  _CALLCUSTOM.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLCUSTOM.fields_by_name['sender_user_id']._options = None
  _CALLCUSTOM.fields_by_name['sender_user_id']._serialized_options = b'\372B\004r\002\020\001'
  _CALLCUSTOM.fields_by_name['type']._options = None
  _CALLCUSTOM.fields_by_name['type']._serialized_options = b'\372B\004r\002\020\001'
  _RECORDINGSTARTED._serialized_start=141
  _RECORDINGSTARTED._serialized_end=302
  _RECORDINGSTOPPED._serialized_start=305
  _RECORDINGSTOPPED._serialized_end=466
  _USERUPDATED._serialized_start=468
  _USERUPDATED._serialized_end=507
  _BROADCASTSTARTED._serialized_start=510
  _BROADCASTSTARTED._serialized_end=671
  _BROADCASTENDED._serialized_start=674
  _BROADCASTENDED._serialized_end=833
  _CALLMEMBERSCREATED._serialized_start=836
  _CALLMEMBERSCREATED._serialized_end=1016
  _CALLMEMBERSUPDATED._serialized_start=1019
  _CALLMEMBERSUPDATED._serialized_end=1182
  _CALLMEMBERSDELETED._serialized_start=1185
  _CALLMEMBERSDELETED._serialized_end=1348
  _CALLCREATED._serialized_start=1351
  _CALLCREATED._serialized_end=1524
  _CALLUPDATED._serialized_start=1527
  _CALLUPDATED._serialized_end=1683
  _CALLENDED._serialized_start=1686
  _CALLENDED._serialized_end=1840
  _CALLDELETED._serialized_start=1843
  _CALLDELETED._serialized_end=1999
  _CALLACCEPTED._serialized_start=2002
  _CALLACCEPTED._serialized_end=2192
  _CALLREJECTED._serialized_start=2195
  _CALLREJECTED._serialized_end=2385
  _CALLCANCELLED._serialized_start=2388
  _CALLCANCELLED._serialized_end=2579
  _CALLCUSTOM._serialized_start=2582
  _CALLCUSTOM._serialized_end=2812
# @@protoc_insertion_point(module_scope)
