# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: permissions/permissions_v1_rpc/permissions.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0permissions/permissions_v1_rpc/permissions.proto\x12%stream.permissions.permissions_v1_rpc\x1a\x1fgoogle/protobuf/timestamp.proto\"!\n\x11\x43reateRoleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"O\n\x12\x43reateRoleResponse\x12\x39\n\x04role\x18\x01 \x01(\x0b\x32+.stream.permissions.permissions_v1_rpc.Role\"!\n\x11\x44\x65leteRoleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteRoleResponse\"\x13\n\x11QueryRolesRequest\"P\n\x12QueryRolesResponse\x12:\n\x05roles\x18\x01 \x03(\x0b\x32+.stream.permissions.permissions_v1_rpc.Role\"\x15\n\x13QueryActionsRequest\"V\n\x14QueryActionsResponse\x12>\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32-.stream.permissions.permissions_v1_rpc.Action\"\x19\n\x17QueryPermissionsRequest\"b\n\x18QueryPermissionsResponse\x12\x46\n\x0bpermissions\x18\x01 \x03(\x0b\x32\x31.stream.permissions.permissions_v1_rpc.Permission\"\xdb\x01\n\x12UpdateScopeRequest\x12\x10\n\x08scope_id\x18\x01 \x01(\t\x12U\n\x06grants\x18\x02 \x03(\x0b\x32\x45.stream.permissions.permissions_v1_rpc.UpdateScopeRequest.GrantsEntry\x1a\\\n\x0bGrantsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12<\n\x05value\x18\x02 \x01(\x0b\x32-.stream.permissions.permissions_v1_rpc.Grants:\x02\x38\x01\"4\n\x11ResetScopeRequest\x12\x10\n\x08scope_id\x18\x01 \x01(\t\x12\r\n\x05roles\x18\x02 \x03(\t\"Q\n\x12ResetScopeResponse\x12;\n\x05scope\x18\x01 \x01(\x0b\x32,.stream.permissions.permissions_v1_rpc.Scope\"R\n\x13UpdateScopeResponse\x12;\n\x05scope\x18\x01 \x01(\x0b\x32,.stream.permissions.permissions_v1_rpc.Scope\"\x14\n\x12QueryScopesRequest\"\xca\x01\n\x13QueryScopesResponse\x12V\n\x06scopes\x18\x01 \x03(\x0b\x32\x46.stream.permissions.permissions_v1_rpc.QueryScopesResponse.ScopesEntry\x1a[\n\x0bScopesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.stream.permissions.permissions_v1_rpc.Scope:\x02\x38\x01\"9\n\x06\x41\x63tion\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04tags\x18\x03 \x03(\t\"\xb7\x01\n\nPermission\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\t\x12H\n\x06simple\x18\x05 \x01(\x0b\x32\x36.stream.permissions.permissions_v1_rpc.SimpleConditionH\x00\x12\x13\n\tcustom_mq\x18\x06 \x01(\x0cH\x00\x42\x0b\n\tcondition\"3\n\x0fSimpleCondition\x12\r\n\x05owner\x18\x01 \x01(\x08\x12\x11\n\tsame_team\x18\x02 \x01(\x08\"D\n\x04Role\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xd0\x01\n\x05Scope\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12H\n\x06grants\x18\x03 \x03(\x0b\x32\x38.stream.permissions.permissions_v1_rpc.Scope.GrantsEntry\x1a\\\n\x0bGrantsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12<\n\x05value\x18\x02 \x01(\x0b\x32-.stream.permissions.permissions_v1_rpc.Grants:\x02\x38\x01\"+\n\x06Grants\x12\x0c\n\x04role\x18\x01 \x01(\t\x12\x13\n\x0bpermissions\x18\x02 \x03(\t2\xce\x08\n\x0ePermissionsRPC\x12\x81\x01\n\nCreateRole\x12\x38.stream.permissions.permissions_v1_rpc.CreateRoleRequest\x1a\x39.stream.permissions.permissions_v1_rpc.CreateRoleResponse\x12\x81\x01\n\nDeleteRole\x12\x38.stream.permissions.permissions_v1_rpc.DeleteRoleRequest\x1a\x39.stream.permissions.permissions_v1_rpc.DeleteRoleResponse\x12\x81\x01\n\nQueryRoles\x12\x38.stream.permissions.permissions_v1_rpc.QueryRolesRequest\x1a\x39.stream.permissions.permissions_v1_rpc.QueryRolesResponse\x12\x84\x01\n\x0bQueryScopes\x12\x39.stream.permissions.permissions_v1_rpc.QueryScopesRequest\x1a:.stream.permissions.permissions_v1_rpc.QueryScopesResponse\x12\x84\x01\n\x0bUpdateScope\x12\x39.stream.permissions.permissions_v1_rpc.UpdateScopeRequest\x1a:.stream.permissions.permissions_v1_rpc.UpdateScopeResponse\x12\x81\x01\n\nResetScope\x12\x38.stream.permissions.permissions_v1_rpc.ResetScopeRequest\x1a\x39.stream.permissions.permissions_v1_rpc.ResetScopeResponse\x12\x87\x01\n\x0cQueryActions\x12:.stream.permissions.permissions_v1_rpc.QueryActionsRequest\x1a;.stream.permissions.permissions_v1_rpc.QueryActionsResponse\x12\x93\x01\n\x10QueryPermissions\x12>.stream.permissions.permissions_v1_rpc.QueryPermissionsRequest\x1a?.stream.permissions.permissions_v1_rpc.QueryPermissionsResponseB7B\rPermissionsV1P\x01Z\x12permissions_v1_rpc\xaa\x02\x0fStream.Video.v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'permissions.permissions_v1_rpc.permissions_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\rPermissionsV1P\001Z\022permissions_v1_rpc\252\002\017Stream.Video.v1'
  _UPDATESCOPEREQUEST_GRANTSENTRY._options = None
  _UPDATESCOPEREQUEST_GRANTSENTRY._serialized_options = b'8\001'
  _QUERYSCOPESRESPONSE_SCOPESENTRY._options = None
  _QUERYSCOPESRESPONSE_SCOPESENTRY._serialized_options = b'8\001'
  _SCOPE_GRANTSENTRY._options = None
  _SCOPE_GRANTSENTRY._serialized_options = b'8\001'
  _CREATEROLEREQUEST._serialized_start=124
  _CREATEROLEREQUEST._serialized_end=157
  _CREATEROLERESPONSE._serialized_start=159
  _CREATEROLERESPONSE._serialized_end=238
  _DELETEROLEREQUEST._serialized_start=240
  _DELETEROLEREQUEST._serialized_end=273
  _DELETEROLERESPONSE._serialized_start=275
  _DELETEROLERESPONSE._serialized_end=295
  _QUERYROLESREQUEST._serialized_start=297
  _QUERYROLESREQUEST._serialized_end=316
  _QUERYROLESRESPONSE._serialized_start=318
  _QUERYROLESRESPONSE._serialized_end=398
  _QUERYACTIONSREQUEST._serialized_start=400
  _QUERYACTIONSREQUEST._serialized_end=421
  _QUERYACTIONSRESPONSE._serialized_start=423
  _QUERYACTIONSRESPONSE._serialized_end=509
  _QUERYPERMISSIONSREQUEST._serialized_start=511
  _QUERYPERMISSIONSREQUEST._serialized_end=536
  _QUERYPERMISSIONSRESPONSE._serialized_start=538
  _QUERYPERMISSIONSRESPONSE._serialized_end=636
  _UPDATESCOPEREQUEST._serialized_start=639
  _UPDATESCOPEREQUEST._serialized_end=858
  _UPDATESCOPEREQUEST_GRANTSENTRY._serialized_start=766
  _UPDATESCOPEREQUEST_GRANTSENTRY._serialized_end=858
  _RESETSCOPEREQUEST._serialized_start=860
  _RESETSCOPEREQUEST._serialized_end=912
  _RESETSCOPERESPONSE._serialized_start=914
  _RESETSCOPERESPONSE._serialized_end=995
  _UPDATESCOPERESPONSE._serialized_start=997
  _UPDATESCOPERESPONSE._serialized_end=1079
  _QUERYSCOPESREQUEST._serialized_start=1081
  _QUERYSCOPESREQUEST._serialized_end=1101
  _QUERYSCOPESRESPONSE._serialized_start=1104
  _QUERYSCOPESRESPONSE._serialized_end=1306
  _QUERYSCOPESRESPONSE_SCOPESENTRY._serialized_start=1215
  _QUERYSCOPESRESPONSE_SCOPESENTRY._serialized_end=1306
  _ACTION._serialized_start=1308
  _ACTION._serialized_end=1365
  _PERMISSION._serialized_start=1368
  _PERMISSION._serialized_end=1551
  _SIMPLECONDITION._serialized_start=1553
  _SIMPLECONDITION._serialized_end=1604
  _ROLE._serialized_start=1606
  _ROLE._serialized_end=1674
  _SCOPE._serialized_start=1677
  _SCOPE._serialized_end=1885
  _SCOPE_GRANTSENTRY._serialized_start=766
  _SCOPE_GRANTSENTRY._serialized_end=858
  _GRANTS._serialized_start=1887
  _GRANTS._serialized_end=1930
  _PERMISSIONSRPC._serialized_start=1933
  _PERMISSIONSRPC._serialized_end=3035
# @@protoc_insertion_point(module_scope)
