"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Codec:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CodecEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Codec.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CODEC_H264_UNSPECIFIED: _Codec.ValueType  # 0
    CODEC_VP8: _Codec.ValueType  # 1
    CODEC_VP9: _Codec.ValueType  # 2

class Codec(_Codec, metaclass=_CodecEnumTypeWrapper): ...

CODEC_H264_UNSPECIFIED: Codec.ValueType  # 0
CODEC_VP8: Codec.ValueType  # 1
CODEC_VP9: Codec.ValueType  # 2
global___Codec = Codec

class RTMPOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URLS_FIELD_NUMBER: builtins.int
    @property
    def urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        urls: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["urls", b"urls"]) -> None: ...

global___RTMPOptions = RTMPOptions

class Broadcast(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RTMP_FIELD_NUMBER: builtins.int
    HLS_URL_FIELD_NUMBER: builtins.int
    @property
    def rtmp(self) -> global___RTMPOptions: ...
    hls_url: builtins.str
    def __init__(
        self,
        *,
        rtmp: global___RTMPOptions | None = ...,
        hls_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rtmp", b"rtmp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hls_url", b"hls_url", "rtmp", b"rtmp"]) -> None: ...

global___Broadcast = Broadcast
