# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/call_v1/call.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from validate import validate_pb2 as validate_dot_validate__pb2
from video.coordinator.member_v1 import member_pb2 as video_dot_coordinator_dot_member__v1_dot_member__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$video/coordinator/call_v1/call.proto\x12 stream.video.coordinator.call_v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\x1a(video/coordinator/member_v1/member.proto\"\xb8\x01\n\x08\x43\x61llType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\x07options\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallOptions\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9e\x02\n\x04\x43\x61ll\x12\x15\n\x04type\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x13\n\x02id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x10\n\x08\x63\x61ll_cid\x18\x03 \x01(\t\x12#\n\x12\x63reated_by_user_id\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x13\n\x0b\x63ustom_json\x18\x05 \x01(\x0c\x12>\n\x07options\x18\x06 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallOptions\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x8f\x02\n\x0b\x43\x61llDetails\x12>\n\x07options\x18\x01 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallOptions\x12\x17\n\x0fmember_user_ids\x18\x02 \x03(\t\x12K\n\x07members\x18\x03 \x03(\x0b\x32:.stream.video.coordinator.call_v1.CallDetails.MembersEntry\x1aZ\n\x0cMembersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.stream.video.coordinator.member_v1.Member:\x02\x38\x01\"\xa1\x01\n\x0b\x43\x61llOptions\x12\x45\n\trecording\x18\x01 \x01(\x0b\x32\x32.stream.video.coordinator.call_v1.RecordingOptions\x12K\n\x0c\x62roadcasting\x18\x02 \x01(\x0b\x32\x35.stream.video.coordinator.call_v1.BroadcastingOptions\"4\n\x10RecordingOptions\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\n\n\x08_enabled\"7\n\x13\x42roadcastingOptions\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\n\n\x08_enabledB1B\x06\x43\x61llV1P\x01Z\x07\x63\x61ll_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.call_v1.call_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\006CallV1P\001Z\007call_v1\252\002\033Stream.Video.v1.Coordinator'
  _CALL.fields_by_name['type']._options = None
  _CALL.fields_by_name['type']._serialized_options = b'\372B\004r\002\020\001'
  _CALL.fields_by_name['id']._options = None
  _CALL.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _CALL.fields_by_name['created_by_user_id']._options = None
  _CALL.fields_by_name['created_by_user_id']._serialized_options = b'\372B\004r\002\020\001'
  _CALLDETAILS_MEMBERSENTRY._options = None
  _CALLDETAILS_MEMBERSENTRY._serialized_options = b'8\001'
  _CALLTYPE._serialized_start=175
  _CALLTYPE._serialized_end=359
  _CALL._serialized_start=362
  _CALL._serialized_end=648
  _CALLDETAILS._serialized_start=651
  _CALLDETAILS._serialized_end=922
  _CALLDETAILS_MEMBERSENTRY._serialized_start=832
  _CALLDETAILS_MEMBERSENTRY._serialized_end=922
  _CALLOPTIONS._serialized_start=925
  _CALLOPTIONS._serialized_end=1086
  _RECORDINGOPTIONS._serialized_start=1088
  _RECORDINGOPTIONS._serialized_end=1140
  _BROADCASTINGOPTIONS._serialized_start=1142
  _BROADCASTINGOPTIONS._serialized_end=1197
# @@protoc_insertion_point(module_scope)
