"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import video.coordinator.user_v1.user_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Participant(google.protobuf.message.Message):
    """those who are online in the call"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    VIDEO_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> video.coordinator.user_v1.user_pb2.User: ...
    role: builtins.str
    online: builtins.bool
    custom_json: builtins.bytes
    video: builtins.bool
    audio: builtins.bool
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Call creation date."""
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Call last update date."""
    def __init__(
        self,
        *,
        user: video.coordinator.user_v1.user_pb2.User | None = ...,
        role: builtins.str = ...,
        online: builtins.bool = ...,
        custom_json: builtins.bytes = ...,
        video: builtins.bool = ...,
        audio: builtins.bool = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "updated_at", b"updated_at", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio", b"audio", "created_at", b"created_at", "custom_json", b"custom_json", "online", b"online", "role", b"role", "updated_at", b"updated_at", "user", b"user", "video", b"video"]) -> None: ...

global___Participant = Participant

class ParticipantRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    role: builtins.str
    custom_json: builtins.bytes
    """Call custom data"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Call creation date."""
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Call last update date."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        role: builtins.str = ...,
        custom_json: builtins.bytes = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "custom_json", b"custom_json", "role", b"role", "updated_at", b"updated_at", "user_id", b"user_id"]) -> None: ...

global___ParticipantRequest = ParticipantRequest
