# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/push_v1/push.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$video/coordinator/push_v1/push.proto\x12 stream.video.coordinator.push_v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xce\x03\n\x0cPushProvider\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12\x17\n\x0f\x64isabled_reason\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x03\x61pn\x18\x06 \x01(\x0b\x32\x30.stream.video.coordinator.push_v1.ApnCredentialsH\x00\x12I\n\x08\x66irebase\x18\x07 \x01(\x0b\x32\x35.stream.video.coordinator.push_v1.FirebaseCredentialsH\x00\x12\x45\n\x06huawei\x18\x08 \x01(\x0b\x32\x33.stream.video.coordinator.push_v1.HuaweiCredentialsH\x00\x12\x45\n\x06xiaomi\x18\t \x01(\x0b\x32\x33.stream.video.coordinator.push_v1.XiaomiCredentialsH\x00\x42\r\n\x0b\x63redentials\"k\n\x0e\x41pnCredentials\x12\x10\n\x08\x61uth_key\x18\x01 \x01(\t\x12\x0e\n\x06key_id\x18\x02 \x01(\t\x12\x11\n\tapn_topic\x18\x03 \x01(\t\x12\x0f\n\x07team_id\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65velopment\x18\x05 \x01(\x08\"C\n\x13\x46irebaseCredentials\x12\x12\n\nserver_key\x18\x01 \x01(\t\x12\x18\n\x10\x63redentials_json\x18\x02 \x01(\t\"/\n\x11HuaweiCredentials\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"9\n\x11XiaomiCredentials\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\xcc\x01\n\x06\x44\x65vice\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12\x17\n\x0f\x64isabled_reason\x18\x04 \x01(\t\x12\x1a\n\x12push_provider_name\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"3\n\x0b\x44\x65viceInput\x12\n\n\x02id\x18\x01 \x01(\t\x12\x18\n\x10push_provider_id\x18\x02 \x01(\tB1B\x06PushV1P\x01Z\x07push_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.push_v1.push_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\006PushV1P\001Z\007push_v1\252\002\033Stream.Video.v1.Coordinator'
  _PUSHPROVIDER._serialized_start=108
  _PUSHPROVIDER._serialized_end=570
  _APNCREDENTIALS._serialized_start=572
  _APNCREDENTIALS._serialized_end=679
  _FIREBASECREDENTIALS._serialized_start=681
  _FIREBASECREDENTIALS._serialized_end=748
  _HUAWEICREDENTIALS._serialized_start=750
  _HUAWEICREDENTIALS._serialized_end=797
  _XIAOMICREDENTIALS._serialized_start=799
  _XIAOMICREDENTIALS._serialized_end=856
  _DEVICE._serialized_start=859
  _DEVICE._serialized_end=1063
  _DEVICEINPUT._serialized_start=1065
  _DEVICEINPUT._serialized_end=1116
# @@protoc_insertion_point(module_scope)
