# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/app_v1/app.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"video/coordinator/app_v1/app.proto\x12\x1fstream.video.coordinator.app_v1\"T\n\x03\x41pp\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x41\n\x07webhook\x18\x02 \x01(\x0b\x32\x30.stream.video.coordinator.app_v1.WebhookSettings\"\x87\x01\n\x0fWebhookSettings\x12:\n\x04http\x18\x01 \x01(\x0b\x32,.stream.video.coordinator.app_v1.HttpWebhook\x12\x38\n\x03sqs\x18\x02 \x01(\x0b\x32+.stream.video.coordinator.app_v1.SqsWebhook\"\x1a\n\x0bHttpWebhook\x12\x0b\n\x03url\x18\x01 \x01(\t\"6\n\nSqsWebhook\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0e\n\x06secret\x18\x03 \x01(\tB/B\x05\x41ppV1P\x01Z\x06\x61pp_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.app_v1.app_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\005AppV1P\001Z\006app_v1\252\002\033Stream.Video.v1.Coordinator'
  _APP._serialized_start=71
  _APP._serialized_end=155
  _WEBHOOKSETTINGS._serialized_start=158
  _WEBHOOKSETTINGS._serialized_end=293
  _HTTPWEBHOOK._serialized_start=295
  _HTTPWEBHOOK._serialized_end=321
  _SQSWEBHOOK._serialized_start=323
  _SQSWEBHOOK._serialized_end=377
# @@protoc_insertion_point(module_scope)
