# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/videoerr/error.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avideo/videoerr/error.proto\x12\x15stream.video.videoerr*\x8b\x04\n\x01\x45\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x17\n\x12\x41UTH_TOKEN_INVALID\x10\xe9\x07\x12\x1d\n\x18\x41UTH_TOKEN_NOT_VALID_YET\x10\xea\x07\x12!\n\x1c\x41UTH_TOKEN_USED_BEFORE_ISSUE\x10\xeb\x07\x12\x17\n\x12\x41UTH_TOKEN_EXPIRED\x10\xec\x07\x12!\n\x1c\x41UTH_TOKEN_INVALID_SIGNATURE\x10\xed\x07\x12\x19\n\x14\x41PI_KEY_NOT_PROVIDED\x10\xcd\x08\x12\x17\n\x12\x41PI_KEY_IS_UNKNOWN\x10\xce\x08\x12\x16\n\x11PERMISSION_DENIED\x10\xb1\t\x12\x1e\n\x19REQUEST_VALIDATION_FAILED\x10\x95\n\x12\x18\n\x13\x43\x41LL_TYPE_NOT_FOUND\x10\xf9\n\x12\x1d\n\x18\x43\x41LL_TYPE_ALREADY_EXISTS\x10\xfb\n\x12\x13\n\x0e\x43\x41LL_NOT_FOUND\x10\xdd\x0b\x12\x18\n\x13\x43\x41LL_ALREADY_EXISTS\x10\xde\x0b\x12\x1c\n\x17PUSH_PROVIDER_NOT_FOUND\x10\xc1\x0c\x12\x1a\n\x15PUSH_DEVICE_NOT_FOUND\x10\xc2\x0c\x12\x13\n\x0eUSER_NOT_FOUND\x10\xa5\r\x12\x18\n\x13USER_ALREADY_EXISTS\x10\xa6\r\x12!\n\x1cSFU_NO_DATACENTERS_AVAILABLE\x10\x89\x0e\x42\nZ\x08videoerrb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.videoerr.error_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\010videoerr'
  _E._serialized_start=54
  _E._serialized_end=577
# @@protoc_insertion_point(module_scope)
