"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import video.coordinator.call_v1.call_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RecordingStarted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___RecordingStarted = RecordingStarted

class RecordingStopped(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___RecordingStopped = RecordingStopped

class UserUpdated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_id", b"user_id"]) -> None: ...

global___UserUpdated = UserUpdated

class BroadcastStarted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___BroadcastStarted = BroadcastStarted

class BroadcastEnded(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___BroadcastEnded = BroadcastEnded

class CallMembersCreated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    RINGING_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    ringing: builtins.bool
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
        ringing: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details", "ringing", b"ringing"]) -> None: ...

global___CallMembersCreated = CallMembersCreated

class CallMembersUpdated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___CallMembersUpdated = CallMembersUpdated

class CallMembersDeleted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___CallMembersDeleted = CallMembersDeleted

class CallCreated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    RINGING_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    ringing: builtins.bool
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
        ringing: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details", "ringing", b"ringing"]) -> None: ...

global___CallCreated = CallCreated

class CallUpdated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___CallUpdated = CallUpdated

class CallEnded(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___CallEnded = CallEnded

class CallDeleted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> None: ...

global___CallDeleted = CallDeleted

class CallAccepted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    SENDER_USER_ID_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    sender_user_id: builtins.str
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
        sender_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details", "sender_user_id", b"sender_user_id"]) -> None: ...

global___CallAccepted = CallAccepted

class CallRejected(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    SENDER_USER_ID_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    sender_user_id: builtins.str
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
        sender_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details", "sender_user_id", b"sender_user_id"]) -> None: ...

global___CallRejected = CallRejected

class CallCancelled(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    SENDER_USER_ID_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    sender_user_id: builtins.str
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
        sender_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details", "sender_user_id", b"sender_user_id"]) -> None: ...

global___CallCancelled = CallCancelled

class CallCustom(google.protobuf.message.Message):
    """A custom event type"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    CALL_DETAILS_FIELD_NUMBER: builtins.int
    SENDER_USER_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DATA_JSON_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call: ...
    @property
    def call_details(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
    sender_user_id: builtins.str
    type: builtins.str
    """The type of the event"""
    data_json: builtins.bytes
    """The data in the event"""
    def __init__(
        self,
        *,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        call_details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
        sender_user_id: builtins.str = ...,
        type: builtins.str = ...,
        data_json: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "call_details", b"call_details", "data_json", b"data_json", "sender_user_id", b"sender_user_id", "type", b"type"]) -> None: ...

global___CallCustom = CallCustom
