# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/member_v1/member.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(video/coordinator/member_v1/member.proto\x12\"stream.video.coordinator.member_v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\"\xc9\x01\n\x06Member\x12\x19\n\x08\x63\x61ll_cid\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07user_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04role\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x13\n\x0b\x63ustom_json\x18\x04 \x01(\x0c\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB5B\x08MemberV1P\x01Z\tmember_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.member_v1.member_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\010MemberV1P\001Z\tmember_v1\252\002\033Stream.Video.v1.Coordinator'
  _MEMBER.fields_by_name['call_cid']._options = None
  _MEMBER.fields_by_name['call_cid']._serialized_options = b'\372B\004r\002\020\001'
  _MEMBER.fields_by_name['user_id']._options = None
  _MEMBER.fields_by_name['user_id']._serialized_options = b'\372B\004r\002\020\001'
  _MEMBER.fields_by_name['role']._options = None
  _MEMBER.fields_by_name['role']._serialized_options = b'\372B\004r\002\020\001'
  _MEMBER._serialized_start=139
  _MEMBER._serialized_end=340
# @@protoc_insertion_point(module_scope)
