# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/sfu/signal_rpc/signal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video.sfu.models import models_pb2 as video_dot_sfu_dot_models_dot_models__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!video/sfu/signal_rpc/signal.proto\x12\x17stream.video.sfu.signal\x1a\x1dvideo/sfu/models/models.proto\"q\n\x19UpdateVideoQualityRequest\x12@\n\x10stream_qualities\x18\x01 \x03(\x0b\x32&.stream.video.sfu.models.StreamQuality\x12\x12\n\nsession_id\x18\x02 \x01(\t\"\x1c\n\x1aUpdateVideoQualityResponse\"\xc6\x01\n\x16UpdateMuteStateRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12G\n\x12\x61udio_mute_changed\x18\x02 \x01(\x0b\x32).stream.video.sfu.signal.AudioMuteChangedH\x00\x12G\n\x12video_mute_changed\x18\x03 \x01(\x0b\x32).stream.video.sfu.signal.VideoMuteChangedH\x00\x42\x06\n\x04mute\"\x19\n\x17UpdateMuteStateResponse\"!\n\x10\x41udioMuteChanged\x12\r\n\x05muted\x18\x01 \x01(\x08\"!\n\x10VideoMuteChanged\x12\r\n\x05muted\x18\x02 \x01(\x08\"\xee\x01\n\x1aUpdateSubscriptionsRequest\x12]\n\rsubscriptions\x18\x01 \x03(\x0b\x32\x46.stream.video.sfu.signal.UpdateSubscriptionsRequest.SubscriptionsEntry\x12\x12\n\nsession_id\x18\x02 \x01(\t\x1a]\n\x12SubscriptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.stream.video.sfu.models.VideoDimension:\x02\x38\x01\"j\n\x11SendAnswerRequest\x12\x34\n\tpeer_type\x18\x01 \x01(\x0e\x32!.stream.video.sfu.models.PeerType\x12\x0b\n\x03sdp\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x04 \x01(\t\"\x14\n\x12SendAnswerResponse\"\xd9\x01\n\x13IceCandidateRequest\x12\x11\n\tpublisher\x18\x01 \x01(\x08\x12\x11\n\tcandidate\x18\x02 \x01(\t\x12\x14\n\x07sdp_mid\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x1c\n\x0fsdp_mline_index\x18\x04 \x01(\rH\x01\x88\x01\x01\x12\x1e\n\x11username_fragment\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x12\n\nsession_id\x18\x07 \x01(\tB\n\n\x08_sdp_midB\x12\n\x10_sdp_mline_indexB\x14\n\x12_username_fragment\"\x14\n\x12ICETrickleResponse\"\x1d\n\x1bUpdateSubscriptionsResponse\"6\n\x13SetPublisherRequest\x12\x0b\n\x03sdp\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\t\"7\n\x14SetPublisherResponse\x12\x0b\n\x03sdp\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\t\"2\n\x0e\x43onnectRequest\x12\x11\n\tsdp_offer\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"%\n\x0f\x43onnectResponse\x12\x12\n\nsdp_answer\x18\x01 \x01(\t\"\x9c\x01\n\rSignalRequest\x12>\n\tsubscribe\x18\x01 \x01(\x0b\x32).stream.video.sfu.signal.SubscribeRequestH\x00\x12:\n\x07publish\x18\x02 \x01(\x0b\x32\'.stream.video.sfu.signal.PublishRequestH\x00\x42\x0f\n\revent_payload\"\x9c\x01\n\x0bSignalEvent\x12?\n\tsubscribe\x18\x01 \x01(\x0b\x32*.stream.video.sfu.signal.SubscribeResponseH\x00\x12;\n\x07publish\x18\x02 \x01(\x0b\x32(.stream.video.sfu.signal.PublishResponseH\x00\x42\x0f\n\revent_payload\"E\n\x10SubscribeRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x11\n\tsdp_offer\x18\x02 \x01(\t\x12\x0f\n\x07quality\x18\x03 \x01(\t\"$\n\x11SubscribeResponse\x12\x0f\n\x07quality\x18\x02 \x01(\t\"2\n\x0ePublishRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x11\n\tsdp_offer\x18\x02 \x01(\t\"%\n\x0fPublishResponse\x12\x12\n\nsdp_answer\x18\x02 \x01(\t2\xbb\x05\n\x0cSignalServer\x12k\n\x0cSetPublisher\x12,.stream.video.sfu.signal.SetPublisherRequest\x1a-.stream.video.sfu.signal.SetPublisherResponse\x12\x65\n\nSendAnswer\x12*.stream.video.sfu.signal.SendAnswerRequest\x1a+.stream.video.sfu.signal.SendAnswerResponse\x12^\n\nIceTrickle\x12#.stream.video.sfu.models.ICETrickle\x1a+.stream.video.sfu.signal.ICETrickleResponse\x12\x80\x01\n\x13UpdateSubscriptions\x12\x33.stream.video.sfu.signal.UpdateSubscriptionsRequest\x1a\x34.stream.video.sfu.signal.UpdateSubscriptionsResponse\x12t\n\x0fUpdateMuteState\x12/.stream.video.sfu.signal.UpdateMuteStateRequest\x1a\x30.stream.video.sfu.signal.UpdateMuteStateResponse\x12~\n\x13RequestVideoQuality\x12\x32.stream.video.sfu.signal.UpdateVideoQualityRequest\x1a\x33.stream.video.sfu.signal.UpdateVideoQualityResponseB5B\x0bSfuSignalV1P\x01Z\x0esfu_signal_rpc\xaa\x02\x13Stream.Video.v1.Sfub\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.sfu.signal_rpc.signal_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\013SfuSignalV1P\001Z\016sfu_signal_rpc\252\002\023Stream.Video.v1.Sfu'
  _UPDATESUBSCRIPTIONSREQUEST_SUBSCRIPTIONSENTRY._options = None
  _UPDATESUBSCRIPTIONSREQUEST_SUBSCRIPTIONSENTRY._serialized_options = b'8\001'
  _UPDATEVIDEOQUALITYREQUEST._serialized_start=93
  _UPDATEVIDEOQUALITYREQUEST._serialized_end=206
  _UPDATEVIDEOQUALITYRESPONSE._serialized_start=208
  _UPDATEVIDEOQUALITYRESPONSE._serialized_end=236
  _UPDATEMUTESTATEREQUEST._serialized_start=239
  _UPDATEMUTESTATEREQUEST._serialized_end=437
  _UPDATEMUTESTATERESPONSE._serialized_start=439
  _UPDATEMUTESTATERESPONSE._serialized_end=464
  _AUDIOMUTECHANGED._serialized_start=466
  _AUDIOMUTECHANGED._serialized_end=499
  _VIDEOMUTECHANGED._serialized_start=501
  _VIDEOMUTECHANGED._serialized_end=534
  _UPDATESUBSCRIPTIONSREQUEST._serialized_start=537
  _UPDATESUBSCRIPTIONSREQUEST._serialized_end=775
  _UPDATESUBSCRIPTIONSREQUEST_SUBSCRIPTIONSENTRY._serialized_start=682
  _UPDATESUBSCRIPTIONSREQUEST_SUBSCRIPTIONSENTRY._serialized_end=775
  _SENDANSWERREQUEST._serialized_start=777
  _SENDANSWERREQUEST._serialized_end=883
  _SENDANSWERRESPONSE._serialized_start=885
  _SENDANSWERRESPONSE._serialized_end=905
  _ICECANDIDATEREQUEST._serialized_start=908
  _ICECANDIDATEREQUEST._serialized_end=1125
  _ICETRICKLERESPONSE._serialized_start=1127
  _ICETRICKLERESPONSE._serialized_end=1147
  _UPDATESUBSCRIPTIONSRESPONSE._serialized_start=1149
  _UPDATESUBSCRIPTIONSRESPONSE._serialized_end=1178
  _SETPUBLISHERREQUEST._serialized_start=1180
  _SETPUBLISHERREQUEST._serialized_end=1234
  _SETPUBLISHERRESPONSE._serialized_start=1236
  _SETPUBLISHERRESPONSE._serialized_end=1291
  _CONNECTREQUEST._serialized_start=1293
  _CONNECTREQUEST._serialized_end=1343
  _CONNECTRESPONSE._serialized_start=1345
  _CONNECTRESPONSE._serialized_end=1382
  _SIGNALREQUEST._serialized_start=1385
  _SIGNALREQUEST._serialized_end=1541
  _SIGNALEVENT._serialized_start=1544
  _SIGNALEVENT._serialized_end=1700
  _SUBSCRIBEREQUEST._serialized_start=1702
  _SUBSCRIBEREQUEST._serialized_end=1771
  _SUBSCRIBERESPONSE._serialized_start=1773
  _SUBSCRIBERESPONSE._serialized_end=1809
  _PUBLISHREQUEST._serialized_start=1811
  _PUBLISHREQUEST._serialized_end=1861
  _PUBLISHRESPONSE._serialized_start=1863
  _PUBLISHRESPONSE._serialized_end=1900
  _SIGNALSERVER._serialized_start=1903
  _SIGNALSERVER._serialized_end=2602
# @@protoc_insertion_point(module_scope)
