# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/sfu/event/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video.sfu.models import models_pb2 as video_dot_sfu_dot_models_dot_models__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cvideo/sfu/event/events.proto\x12\x16stream.video.sfu.event\x1a\x1dvideo/sfu/models/models.proto\"\xa2\x08\n\x08SfuEvent\x12\x43\n\x10subscriber_offer\x18\x01 \x01(\x0b\x32\'.stream.video.sfu.event.SubscriberOfferH\x00\x12\x43\n\x10publisher_answer\x18\x0e \x01(\x0b\x32\'.stream.video.sfu.event.PublisherAnswerH\x00\x12V\n\x1a\x63onnection_quality_changed\x18\x02 \x01(\x0b\x32\x30.stream.video.sfu.event.ConnectionQualityChangedH\x00\x12H\n\x13\x61udio_level_changed\x18\x03 \x01(\x0b\x32).stream.video.sfu.event.AudioLevelChangedH\x00\x12:\n\x0bice_trickle\x18\x04 \x01(\x0b\x32#.stream.video.sfu.models.ICETrickleH\x00\x12N\n\x16\x63hange_publish_quality\x18\x06 \x01(\x0b\x32,.stream.video.sfu.event.ChangePublishQualityH\x00\x12H\n\x13local_device_change\x18\x07 \x01(\x0b\x32).stream.video.sfu.event.LocalDeviceChangeH\x00\x12\x46\n\x12mute_state_changed\x18\x08 \x01(\x0b\x32(.stream.video.sfu.event.MuteStateChangedH\x00\x12L\n\x15video_quality_changed\x18\t \x01(\x0b\x32+.stream.video.sfu.event.VideoQualityChangedH\x00\x12G\n\x12participant_joined\x18\n \x01(\x0b\x32).stream.video.sfu.event.ParticipantJoinedH\x00\x12\x43\n\x10participant_left\x18\x0b \x01(\x0b\x32\'.stream.video.sfu.event.ParticipantLeftH\x00\x12R\n\x18\x64ominant_speaker_changed\x18\x0c \x01(\x0b\x32..stream.video.sfu.event.DominantSpeakerChangedH\x00\x12=\n\rjoin_response\x18\r \x01(\x0b\x32$.stream.video.sfu.event.JoinResponseH\x00\x12L\n\x15health_check_response\x18\x0f \x01(\x0b\x32+.stream.video.sfu.event.HealthCheckResponseH\x00\x42\x0f\n\revent_payload\"\xa8\x01\n\nSfuRequest\x12;\n\x0cjoin_request\x18\x01 \x01(\x0b\x32#.stream.video.sfu.event.JoinRequestH\x00\x12J\n\x14health_check_request\x18\x02 \x01(\x0b\x32*.stream.video.sfu.event.HealthCheckRequestH\x00\x42\x11\n\x0frequest_payload\"(\n\x12HealthCheckRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\")\n\x13HealthCheckResponse\x12\x12\n\nsession_id\x18\x01 \x01(\t\"\x81\x01\n\x0bJoinRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x0f\n\x07publish\x18\x03 \x01(\x08\x12>\n\x0e\x63odec_settings\x18\x04 \x01(\x0b\x32&.stream.video.sfu.models.CodecSettings\"^\n\x0cJoinResponse\x12\x36\n\ncall_state\x18\x01 \x01(\x0b\x32\".stream.video.sfu.models.CallState\x12\x16\n\x0eown_session_id\x18\x02 \x01(\t\"{\n\x11ParticipantJoined\x12+\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x1d.stream.video.sfu.models.Call\x12\x39\n\x0bparticipant\x18\x02 \x01(\x0b\x32$.stream.video.sfu.models.Participant\"y\n\x0fParticipantLeft\x12+\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32\x1d.stream.video.sfu.models.Call\x12\x39\n\x0bparticipant\x18\x02 \x01(\x0b\x32$.stream.video.sfu.models.Participant\"M\n\x10MuteStateChanged\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x13\n\x0b\x61udio_muted\x18\x02 \x01(\x08\x12\x13\n\x0bvideo_muted\x18\x03 \x01(\x08\"W\n\x13VideoQualityChanged\x12@\n\x10stream_qualities\x18\x01 \x03(\x0b\x32&.stream.video.sfu.models.StreamQuality\"\x1e\n\x0fSubscriberOffer\x12\x0b\n\x03sdp\x18\x01 \x01(\t\"\x1e\n\x0fPublisherAnswer\x12\x0b\n\x03sdp\x18\x01 \x01(\t\"!\n\x11LocalDeviceChange\x12\x0c\n\x04type\x18\x01 \x01(\t\"(\n\x13ICECandidateTrickle\x12\x11\n\tcandidate\x18\x01 \x01(\t\"s\n\x18\x43onnectionQualityChanged\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x46\n\x12\x63onnection_quality\x18\x02 \x01(\x0e\x32*.stream.video.sfu.models.ConnectionQuality\")\n\x16\x44ominantSpeakerChanged\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"M\n\x11\x41udioLevelChanged\x12\x38\n\x0c\x61udio_levels\x18\x01 \x03(\x0b\x32\".stream.video.sfu.event.AudioLevel\",\n\nAudioLevel\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\x02\"\x13\n\x11\x41udioLayerSetting\"*\n\x11\x41udioMediaRequest\x12\x15\n\rchannel_count\x18\x01 \x01(\x05\"\xb9\x01\n\x0b\x41udioSender\x12@\n\rmedia_request\x18\x01 \x01(\x0b\x32).stream.video.sfu.event.AudioMediaRequest\x12-\n\x05\x63odec\x18\x02 \x01(\x0b\x32\x1e.stream.video.sfu.models.Codec\x12\x39\n\x06layers\x18\x03 \x03(\x0b\x32).stream.video.sfu.event.AudioLayerSetting\"X\n\x11VideoMediaRequest\x12\x14\n\x0cideal_height\x18\x01 \x01(\x05\x12\x13\n\x0bideal_width\x18\x02 \x01(\x05\x12\x18\n\x10ideal_frame_rate\x18\x03 \x01(\x05\"\xc6\x02\n\x11VideoLayerSetting\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\x13\n\x0bmax_bitrate\x18\x03 \x01(\x05\x12 \n\x18scale_resolution_down_by\x18\x04 \x01(\x02\x12\x44\n\x08priority\x18\x05 \x01(\x0e\x32\x32.stream.video.sfu.event.VideoLayerSetting.Priority\x12-\n\x05\x63odec\x18\x06 \x01(\x0b\x32\x1e.stream.video.sfu.models.Codec\"g\n\x08Priority\x12\x1d\n\x19PRIORITY_HIGH_UNSPECIFIED\x10\x00\x12\x10\n\x0cPRIORITY_LOW\x10\x01\x12\x13\n\x0fPRIORITY_MEDIUM\x10\x02\x12\x15\n\x11PRIORITY_VERY_LOW\x10\x03\"\xb9\x01\n\x0bVideoSender\x12@\n\rmedia_request\x18\x01 \x01(\x0b\x32).stream.video.sfu.event.VideoMediaRequest\x12-\n\x05\x63odec\x18\x02 \x01(\x0b\x32\x1e.stream.video.sfu.models.Codec\x12\x39\n\x06layers\x18\x03 \x03(\x0b\x32).stream.video.sfu.event.VideoLayerSetting\"\x8e\x01\n\x14\x43hangePublishQuality\x12:\n\raudio_senders\x18\x01 \x03(\x0b\x32#.stream.video.sfu.event.AudioSender\x12:\n\rvideo_senders\x18\x02 \x03(\x0b\x32#.stream.video.sfu.event.VideoSenderB1B\x0bSfuEventsV1P\x01Z\nsfu_events\xaa\x02\x13Stream.Video.v1.Sfub\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.sfu.event.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\013SfuEventsV1P\001Z\nsfu_events\252\002\023Stream.Video.v1.Sfu'
  _SFUEVENT._serialized_start=88
  _SFUEVENT._serialized_end=1146
  _SFUREQUEST._serialized_start=1149
  _SFUREQUEST._serialized_end=1317
  _HEALTHCHECKREQUEST._serialized_start=1319
  _HEALTHCHECKREQUEST._serialized_end=1359
  _HEALTHCHECKRESPONSE._serialized_start=1361
  _HEALTHCHECKRESPONSE._serialized_end=1402
  _JOINREQUEST._serialized_start=1405
  _JOINREQUEST._serialized_end=1534
  _JOINRESPONSE._serialized_start=1536
  _JOINRESPONSE._serialized_end=1630
  _PARTICIPANTJOINED._serialized_start=1632
  _PARTICIPANTJOINED._serialized_end=1755
  _PARTICIPANTLEFT._serialized_start=1757
  _PARTICIPANTLEFT._serialized_end=1878
  _MUTESTATECHANGED._serialized_start=1880
  _MUTESTATECHANGED._serialized_end=1957
  _VIDEOQUALITYCHANGED._serialized_start=1959
  _VIDEOQUALITYCHANGED._serialized_end=2046
  _SUBSCRIBEROFFER._serialized_start=2048
  _SUBSCRIBEROFFER._serialized_end=2078
  _PUBLISHERANSWER._serialized_start=2080
  _PUBLISHERANSWER._serialized_end=2110
  _LOCALDEVICECHANGE._serialized_start=2112
  _LOCALDEVICECHANGE._serialized_end=2145
  _ICECANDIDATETRICKLE._serialized_start=2147
  _ICECANDIDATETRICKLE._serialized_end=2187
  _CONNECTIONQUALITYCHANGED._serialized_start=2189
  _CONNECTIONQUALITYCHANGED._serialized_end=2304
  _DOMINANTSPEAKERCHANGED._serialized_start=2306
  _DOMINANTSPEAKERCHANGED._serialized_end=2347
  _AUDIOLEVELCHANGED._serialized_start=2349
  _AUDIOLEVELCHANGED._serialized_end=2426
  _AUDIOLEVEL._serialized_start=2428
  _AUDIOLEVEL._serialized_end=2472
  _AUDIOLAYERSETTING._serialized_start=2474
  _AUDIOLAYERSETTING._serialized_end=2493
  _AUDIOMEDIAREQUEST._serialized_start=2495
  _AUDIOMEDIAREQUEST._serialized_end=2537
  _AUDIOSENDER._serialized_start=2540
  _AUDIOSENDER._serialized_end=2725
  _VIDEOMEDIAREQUEST._serialized_start=2727
  _VIDEOMEDIAREQUEST._serialized_end=2815
  _VIDEOLAYERSETTING._serialized_start=2818
  _VIDEOLAYERSETTING._serialized_end=3144
  _VIDEOLAYERSETTING_PRIORITY._serialized_start=3041
  _VIDEOLAYERSETTING_PRIORITY._serialized_end=3144
  _VIDEOSENDER._serialized_start=3147
  _VIDEOSENDER._serialized_end=3332
  _CHANGEPUBLISHQUALITY._serialized_start=3335
  _CHANGEPUBLISHQUALITY._serialized_end=3477
# @@protoc_insertion_point(module_scope)
