# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/participant_v1/participant.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from video.coordinator.user_v1 import user_pb2 as video_dot_coordinator_dot_user__v1_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2video/coordinator/participant_v1/participant.proto\x12\'stream.video.coordinator.participant_v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$video/coordinator/user_v1/user.proto\"\xf4\x01\n\x0bParticipant\x12\x34\n\x04user\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.user_v1.User\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x0e\n\x06online\x18\x03 \x01(\x08\x12\x13\n\x0b\x63ustom_json\x18\x04 \x01(\x0c\x12\r\n\x05video\x18\x05 \x01(\x08\x12\r\n\x05\x61udio\x18\x06 \x01(\x08\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa8\x01\n\x12ParticipantRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x13\n\x0b\x63ustom_json\x18\x03 \x01(\x0c\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB?B\rParticipantV1P\x01Z\x0eparticipant_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.participant_v1.participant_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\rParticipantV1P\001Z\016participant_v1\252\002\033Stream.Video.v1.Coordinator'
  _PARTICIPANT._serialized_start=167
  _PARTICIPANT._serialized_end=411
  _PARTICIPANTREQUEST._serialized_start=414
  _PARTICIPANTREQUEST._serialized_end=582
# @@protoc_insertion_point(module_scope)
